@@ -27,6 +27,10 @@
 --
 --
 -- $Log: check_files.c,v $
+-- Revision 1.10  2009/07/07 03:15:41  jsedwards
+-- Added check so that it doesn't try to check a file that doesn't have the
+-- file data stored in the archive.
+--
 -- Revision 1.9  2009/03/10 02:54:44  jsedwards
 -- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
 --
@@ -273,6 +277,10 @@ int main(int argc, char* argv[])
 			    num_failures++;
 			    result = false;
 			}
+			else if (is_void_reference(&file_obj.block_list))
+			{
+			    printf("  File data NOT stored!\n");
+			}
 			else
 			{
 			    if (!nwos_restore_file(&assoc_ref, NULL))     /* calling restore_file with no file name just verfies the file */
