@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,20 @@
 --
 --
 -- $Log: class_definition.c,v $
+-- Revision 1.33  2009/03/10 10:16:17  jsedwards
+-- Moved MAX_CLASS_DEFINITION_SIZE and MAX_FEATURE_NAME_SIZE defines to
+-- class_definition.h file and renamed with _OBJ_SIZE suffix instead of _SIZE.
+--
+-- Revision 1.32  2009/03/09 14:00:41  jsedwards
+-- Eliminated use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.31  2009/03/08 06:47:22  jsedwards
+-- Removed include objectify_private.h and changed include objectify.h to
+-- class_definition.h.  Moved class reference global variables
+-- from objectify.c.  Changed calls to nwos_generate_new_completely_random_id
+-- nwos_generate_new_id, call nwos_is_ready instead of reading nwos_ready flag
+-- directly, and call nwos_is_writable instead of nwos_disk_io_is_read_write.
+--
 -- Revision 1.30  2009/01/31 12:29:12  jsedwards
 -- Moved functions to deal with various file class definitions from objectify.c.
 --
@@ -153,9 +167,13 @@
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "class_definition.h"
 #include "crc32.h"
-#include "objectify.h"
-#include "objectify_private.h"
+
+
+ObjRef nwos_public_class_definition_class_ref;
+ObjRef nwos_private_class_definition_class_ref;
+ObjRef nwos_reference_list_class_ref;
 
 
 static size_t get_class_object_size(void* class_obj)
@@ -172,7 +190,7 @@ static size_t get_class_object_size(void* class_obj)
 
 static size_t feature_size(ObjRef* class_ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     char name[32];
     int i;
@@ -230,7 +248,7 @@ static size_t feature_size(ObjRef* class_ref)
 
 size_t nwos_get_object_size(void* object)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     C_struct_Feature_Definition feature_obj;
     char label[32] = "";
@@ -306,13 +324,13 @@ size_t nwos_get_object_size(void* object)
 
 void nwos_clone_updated_class_definition(ObjRef* old_private_ref, ObjRef* clone_ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     char msg[128];
     ObjRef public_ref;
 
 
-    nwos_generate_new_completely_random_id(clone_ref);
+    nwos_generate_new_id(clone_ref);
 
     assert(nwos_read_variable_sized_object_from_disk(old_private_ref, kludge, sizeof(kludge), &get_class_object_size));
 
@@ -415,7 +433,7 @@ ObjCreateResult nwos_find_or_create_private_class_definition(char* name_of_class
 
 void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     char msg[128];
 
@@ -423,7 +441,7 @@ void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref)
 
     assert(nwos_read_variable_sized_object_from_disk(class_to_clone_ref, kludge, sizeof(kludge), &get_class_object_size));
 
-    nwos_generate_new_completely_random_id(clone_ref);
+    nwos_generate_new_id(clone_ref);
 
     snprintf(msg, sizeof(msg), "clone_class_definition(%02x%02x%02x%02x) -> %02x%02x%02x%02x\n",
 	   class_to_clone_ref->id[0], class_to_clone_ref->id[1], class_to_clone_ref->id[2], class_to_clone_ref->id[3],
@@ -455,7 +473,7 @@ void nwos_clone_class_definition(ObjRef* class_to_clone_ref, ObjRef* clone_ref)
 
 bool nwos_find_public_class_definition(char* name, ObjRef* class_ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     ReferenceList* ref_list;
     int num_classes;
@@ -505,7 +523,7 @@ bool nwos_find_public_class_definition(char* name, ObjRef* class_ref)
 
 bool nwos_find_private_class_definition(char* name, ObjRef* class_ref)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     C_struct_Class_Definition* class_def_obj_ptr = (C_struct_Class_Definition*)kludge;
     ReferenceList* ref_list;
     int num_classes;
@@ -571,7 +589,7 @@ bool nwos_find_class_definition(char* name, ObjRef* class_ref)
 
 void nwos_read_class_definition(ObjRef* ref, C_struct_Class_Definition* class_def)
 {
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_CLASS_DEFINITION_OBJ_SIZE];
     assert(!is_void_reference(ref));
 
     assert(nwos_read_variable_sized_object_from_disk(ref, kludge, sizeof(kludge), get_class_object_size));
@@ -596,7 +614,7 @@ bool nwos_find_public_feature_definition(ObjRef* type_ref, char* label, int coun
     ObjRef label_ref;
     ObjRef feature_class_ref;
     ObjRef object_class;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_FEATURE_NAME_OBJ_SIZE];
     C_struct_Name* ptr_name_obj = (C_struct_Name*)kludge;
     C_struct_Feature_Definition feature_obj;
     ReferenceList* ref_list;
@@ -695,7 +713,7 @@ static void get_file_references()
     int i;
 
     /* can't do anything until everything is initialized */
-    if (nwos_ready && !done)
+    if (nwos_is_ready() && !done)
     {
 	done = true;   /* in case we get called recursively */
 
@@ -803,7 +821,7 @@ ObjRef* nwos_get_file_class_reference()
     }
 #ifndef PUBLIC_MODE
     /* if storage is writable check to see if an updated file class has been created since this was first initialized */
-    else if (nwos_disk_io_is_read_write() && nwos_reference_type(&file_references[2]) == Public_Reference)
+    else if (nwos_is_writable() && nwos_reference_type(&file_references[2]) == Public_Reference)
     {
 	ObjRef class_ref;
 	EveryObject header;
