@@ -27,6 +27,36 @@
 --
 --
 -- $Log: compress_sparse.c,v $
+-- Revision 1.37  2009/07/17 12:41:35  jsedwards
+-- Fixed to loop over USABLE_BLOCKS_PER_CHUNK instead of BLOCKS_IN_CHUNK.
+--
+-- Revision 1.36  2009/07/17 12:30:32  jsedwards
+-- Added chunk reference and block number to warning block print out.  Also
+-- fixed so progress bar is erased and restored when printing warning.
+--
+-- Revision 1.35  2009/07/12 01:46:51  jsedwards
+-- Changed to calculate total blocks from total chunks instead of using
+-- nwos_total_private_blocks and fixed print statement by adding 'll'.
+--
+-- Revision 1.34  2009/07/10 10:19:10  jsedwards
+-- Add code to set the new type_code member of the disk header to "cmpr".
+--
+-- Revision 1.33  2009/07/02 13:02:54  jsedwards
+-- Changed to not copy the header into a disk header structure, instead pass
+-- the buffer to the nwos_load_private_data function which now copies the
+-- header to the private disk header.
+--
+-- Revision 1.32  2009/06/30 13:43:59  jsedwards
+-- Changed to use new disk header functions in the header.c file instead of
+-- having them duplicated in this file.
+--
+-- Revision 1.31  2009/04/21 12:02:07  jsedwards
+-- Change to byte swap chunk_info references as 64 bits and indexs as 32 bits.
+--
+-- Revision 1.30  2009/04/06 14:13:15  jsedwards
+-- Merged in changes from CVS branch_0030_new_chunk_info branch, see revisions
+-- 1.25.2.1 and 1.25.2.2 below.
+--
 -- Revision 1.29  2009/03/14 23:14:04  jsedwards
 -- Added include of the new chunk_info.h file.
 --
@@ -39,6 +69,14 @@
 -- Revision 1.26  2009/03/08 00:06:18  jsedwards
 -- Changed include objectify_private.h to disk_io.h.
 --
+-- Revision 1.25.2.2  2008/08/15 13:30:51  jsedwards
+-- Changed for new Disk_Header with total_chunks instead of total_blocks and
+-- new bit maps preceeding the 16 megabyte chunk.
+--
+-- Revision 1.25.2.1  2008/08/11 13:44:43  jsedwards
+-- Changed to swap new 32-bit "flags_used" member of the chunk_info table
+-- instead of the old "used" member.
+--
 -- Revision 1.25  2008/08/10 15:23:24  jsedwards
 -- Added path to "Missing magic number" and "Incorrect version in header" error
 -- messages.
@@ -170,6 +208,7 @@
 #include "chunk_info.h"
 #include "config.h"
 #include "disk_io.h"
+#include "header.h"
 #include "log.h"
 #include "progress_bar.h"
 #include "user_config.h"
@@ -188,6 +227,7 @@ int main(int argc, char* argv[])
 {
     int obj_file_desc;
     const char* obj_file_path;
+    const char* error_msg;
     off_t chunk;
     uint8 block_map[BIT_MAP_BYTES];
     uint8 block[FILE_BLOCK_SIZE];
@@ -196,12 +236,7 @@ int main(int argc, char* argv[])
     size_t bytes_read;
     FILE* ofp = NULL;
     int num_blocks;
-    uint32 total_private_blocks;
-    uint32 used_private_blocks;
-    uint32 chunk_block_offset;
-    uint32 blocks_on_disk;
     char msg[128];
-    Disk_Header disk_header;
     uint32 counts[SIZE_COUNTS];
     uint32 ref;
     struct md5_ctx md5_context;    /* MD5 checksum context */
@@ -209,7 +244,6 @@ int main(int argc, char* argv[])
     uint8 md5_digest[16];
     uint8 sha1_digest[20];
     int chunk_num;
-    uint32 used_chunks;
     Chunk_Info* chunk_info;
     int blocks_with_bad_ids = 0;
 
@@ -252,33 +286,22 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
-    if (memcmp(&block[0], MAGIC_NUMBER, 4) != 0)
+    error_msg = nwos_load_private_data(block, sizeof(block), false);   /* don't allow compressed files */
+
+    if (error_msg != NULL)
     {
-	fprintf(stderr, "Missing magic number in disk header: %s\n", obj_file_path);
+	fprintf(stderr, "%s: %s\n", error_msg, obj_file_path);
 	exit(1);
     }
 
-    if (memcmp(&block[4], VERSION_STRING, 4) != 0)
-    {
-	fprintf(stderr, "Incorrect version string in disk header: %s\n", obj_file_path);
-	exit(1);
-    }
+    assert(nwos_used_private_chunks > 0);
 
-    memcpy(&disk_header, block, sizeof(disk_header));
-
-    nwos_4_uint8_to_uint32(disk_header.total_blocks, &total_private_blocks);
-    nwos_4_uint8_to_uint32(disk_header.used_blocks, &used_private_blocks);
-    nwos_4_uint8_to_uint32(disk_header.block_offset_to_chunks, &chunk_block_offset);
-    nwos_4_uint8_to_uint32(disk_header.used_chunks, &used_chunks);
-
-    assert(used_chunks > 0);
-
-    chunk_info = malloc(used_chunks * sizeof(Chunk_Info));
+    chunk_info = malloc(nwos_used_private_chunks * sizeof(Chunk_Info));
     assert(chunk_info != NULL);
 
-    bytes_read = read(obj_file_desc, chunk_info, used_chunks * sizeof(Chunk_Info));
+    bytes_read = read(obj_file_desc, chunk_info, nwos_used_private_chunks * sizeof(Chunk_Info));
 
-    if (bytes_read != used_chunks * sizeof(Chunk_Info))
+    if (bytes_read != nwos_used_private_chunks * sizeof(Chunk_Info))
     {
 	perror("reading chunk info");
 	exit(1);
@@ -288,17 +311,15 @@ int main(int argc, char* argv[])
 #ifndef WORDS_BIGENDIAN
 	{
 	  int i;
-	  for (i = 0; i < used_chunks; i++)
+	  for (i = 0; i < nwos_used_private_chunks; i++)
 	  {
-	      chunk_info[i].ref = byteswap_uint32(chunk_info[i].ref);
-	      chunk_info[i].used = byteswap_uint16(chunk_info[i].used);
-	      chunk_info[i].index = byteswap_uint16(chunk_info[i].index);
+	      chunk_info[i].ref = byteswap_uint64(chunk_info[i].ref);
+	      chunk_info[i].flags_used = byteswap_uint32(chunk_info[i].flags_used);
+	      chunk_info[i].index = byteswap_uint32(chunk_info[i].index);
 	  }
 	}
 #endif
 
-    blocks_on_disk = total_private_blocks; 
-
     if (argc == 2)
     {
 	ofp = fopen(argv[1], "w");
@@ -314,12 +335,14 @@ int main(int argc, char* argv[])
     sha1_init_ctx(&sha1_context);
 
     printf("header: %c%c%c%c %c%c%c%c\n",
-	   disk_header.magic_number[0], disk_header.magic_number[1], disk_header.magic_number[2], disk_header.magic_number[3], 
-	   disk_header.version_string[0], disk_header.version_string[1], disk_header.version_string[2], disk_header.version_string[3]);
+	   nwos_private_disk_header.magic_number[0], nwos_private_disk_header.magic_number[1], nwos_private_disk_header.magic_number[2], nwos_private_disk_header.magic_number[3], 
+	   nwos_private_disk_header.version_string[0], nwos_private_disk_header.version_string[1], nwos_private_disk_header.version_string[2], nwos_private_disk_header.version_string[3]);
 
-    printf("total blocks on disk: %08u  chunks_used: %d\n", blocks_on_disk, used_chunks);
+    printf("total blocks on disk: %llu  chunks_used: %d\n", (uint64)nwos_total_private_chunks * USABLE_BLOCKS_PER_CHUNK, nwos_used_private_chunks);
     fflush(stdout);
 
+    memcpy(&(((Disk_Header*)block)->type_code), TYPE_CODE_COMPRESSED, sizeof((((Disk_Header*)block)->type_code)));
+
     /* write the first 256 bytes always */
     if (ofp != NULL && fwrite(block, 1, sizeof(block), ofp) != sizeof(block))
     {
@@ -336,11 +359,11 @@ int main(int argc, char* argv[])
     nwos_start_progress_bar();
 
     // for now we can skip over public blocks because they should always stay the same
-    for (chunk_num = 0; chunk_num < used_chunks; chunk_num++)
+    for (chunk_num = 0; chunk_num < nwos_used_private_chunks; chunk_num++)
     {
-	nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
+	nwos_update_progress_bar((float)num_blocks / (float)nwos_used_private_blocks);
 
-	chunk = chunk_block_offset + chunk_info[chunk_num].index * BLOCKS_IN_CHUNK;
+	chunk = nwos_block_offset_to_chunks + chunk_info[chunk_num].index * BLOCKS_IN_CHUNK;
 
 	if (lseek(obj_file_desc, chunk << 8, SEEK_SET) < 0)
 	{
@@ -358,12 +381,11 @@ int main(int argc, char* argv[])
 	    exit(1);
 	}
 
-	/* scan block map (skip over the blocks for the block map itself) */
-	for (i = BIT_MAP_BLOCKS; i < BLOCKS_IN_CHUNK; i++)
+	for (i = 0; i < USABLE_BLOCKS_PER_CHUNK; i++)
 	{
 	    if ((block_map[i/8] & (0x80 >> (i%8))) != 0)
 	    {
-		if (lseek(obj_file_desc, (chunk + i) << 8, SEEK_SET) < 0)
+		if (lseek(obj_file_desc, (chunk + BIT_MAP_BLOCKS + i) << 8, SEEK_SET) < 0)
 		{
 		    snprintf(msg, sizeof(msg), "lseek block:%08x", (uint32)(chunk + i));
 		    perror(msg);
@@ -383,9 +405,11 @@ int main(int argc, char* argv[])
 
 		if (ref == 0)
 		{
+		    nwos_erase_progress_bar();
+
 		    blocks_with_bad_ids++;
 
-		    printf("WARNING: reference in block is zero, not written:\n");
+		    printf("WARNING: reference in chunk %08llx block %04x is zero, not written:\n", chunk_info[chunk_num].ref, i);
 
 		    for (j = 0; j < FILE_BLOCK_SIZE; j += 16)
 		    {
@@ -394,7 +418,9 @@ int main(int argc, char* argv[])
 			       block[j+4],  block[j+5],  block[j+6],  block[j+7],
 			       block[j+8],  block[j+9],  block[j+10], block[j+11],
 			       block[j+12], block[j+13], block[j+14], block[j+15]);
-		      }
+		    }
+
+		    nwos_start_progress_bar();
 		}
 		else
 		{
