@@ -27,6 +27,15 @@
 --
 --
 -- $Log: disc.c,v $
+-- Revision 1.5  2009/07/19 13:48:32  jsedwards
+-- Moved one of the endifs added in previous check in so that it enclosed the
+-- free that went along with the malloc.
+--
+-- Revision 1.4  2009/07/19 12:43:54  jsedwards
+-- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
+-- were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
 -- Revision 1.3  2009/03/13 12:21:34  jsedwards
 -- Added include of strlcxx.h file.
 --
@@ -431,6 +440,7 @@ ObjCreateResult nwos_create_disc_list(char id[12], ObjRef files[MAX_FILES_PER_DI
 
 	nwos_add_to_references(ref, &disc_class_ref);
 
+#ifdef VERIFY_WRITE
 	ptr_disc_obj = malloc(sizeof(C_struct_Disc_List) + count * sizeof(ObjRef));
 	assert(nwos_read_object_from_disk(ref, ptr_disc_obj, sizeof(C_struct_Disc_List) + count * sizeof(ObjRef)));
 	assert(memcmp(kludge, ptr_disc_obj, sizeof(C_struct_Disc_List) + count * sizeof(ObjRef)) == 0);
@@ -441,6 +451,7 @@ ObjCreateResult nwos_create_disc_list(char id[12], ObjRef files[MAX_FILES_PER_DI
 
 	free(ptr_disc_obj);
 	ptr_disc_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
@@ -518,7 +529,9 @@ bool nwos_find_disc_copy(ObjRef* disc_list, int copy_num, ObjRef* ref)
 ObjCreateResult nwos_create_disc_copy(ObjRef* disc_list, int copy_num, ObjRef* location, ObjRef* ref)
 {
     C_struct_Disc_Copy disc_copy_obj;
+#ifdef VERIFY_WRITE
     C_struct_Disc_Copy* ptr_disc_obj;
+#endif
     ObjRef disc_class_ref;
     ObjCreateResult result = FOUND_EXISTING;
 
@@ -607,12 +620,14 @@ ObjCreateResult nwos_create_disc_copy(ObjRef* disc_list, int copy_num, ObjRef* l
 	nwos_add_to_references(ref, disc_list);
 	nwos_add_to_references(ref, location);
 
+#ifdef VERIFY_WRITE
 	ptr_disc_obj = malloc(sizeof(C_struct_Disc_Copy));
 	assert(nwos_read_object_from_disk(ref, ptr_disc_obj, sizeof(C_struct_Disc_Copy)));
 	assert(memcmp(&disc_copy_obj, ptr_disc_obj, sizeof(C_struct_Disc_Copy)) == 0);
 
 	free(ptr_disc_obj);
 	ptr_disc_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
@@ -691,7 +706,9 @@ bool nwos_find_storage_location(const char* location, ObjRef* ref)
 ObjCreateResult nwos_create_storage_location(const char* location, ObjRef* ref)
 {
     C_struct_Storage_Location location_obj;
+#ifdef VERIFY_WRITE
     C_struct_Storage_Location* ptr_loc_obj;
+#endif
     ObjRef location_class_ref;
     ObjRef name_ref;
     ObjCreateResult result = FOUND_EXISTING;
@@ -725,12 +742,14 @@ ObjCreateResult nwos_create_storage_location(const char* location, ObjRef* ref)
 
 	nwos_add_to_references(ref, &name_ref);
 
+#ifdef VERIFY_WRITE
 	ptr_loc_obj = malloc(sizeof(C_struct_Storage_Location));
 	assert(nwos_read_object_from_disk(ref, ptr_loc_obj, sizeof(C_struct_Storage_Location)));
 	assert(memcmp(&location_obj, ptr_loc_obj, sizeof(C_struct_Storage_Location)) == 0);
 
 	free(ptr_loc_obj);
 	ptr_loc_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
