@@ -27,6 +27,14 @@
 --
 --
 -- $Log: disc_list.c,v $
+-- Revision 1.37  2009/07/19 12:51:18  jsedwards
+-- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
+-- were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
+-- Revision 1.36  2009/06/13 11:37:25  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.35.2.1  2009/06/06 13:41:22  jsedwards
 -- Fix Bug #2740516 - Added new get_disc_id function that calls fgets and
 -- checks return value.
@@ -223,7 +231,9 @@ static size_t get_path_object_size(void* file_path_obj)
 
 void check_for_previous_version_and_link(ObjRef* new_assoc_ref)
 {
+#ifdef VERIFY_WRITE
     C_struct_Path_And_File_Association assoc_obj;
+#endif
     C_struct_Path_And_File_Association old_assoc_obj;
     C_struct_Path_And_File_Association new_assoc_obj;
     uint8 kludge[MAX_PATH_OBJ_SIZE];
@@ -283,11 +293,13 @@ void check_for_previous_version_and_link(ObjRef* new_assoc_ref)
 		   nwos_ref_to_word(&old_assoc_obj.header.common.id),
 		   nwos_ref_to_word(&new_assoc_obj.header.common.id));
 
+#ifdef VERIFY_WRITE
 	    assert(nwos_read_object_from_disk(&old_assoc_obj.header.common.id, &assoc_obj, sizeof(assoc_obj)));
 	    assert(memcmp(&assoc_obj, &old_assoc_obj, sizeof(assoc_obj)) == 0);
 
 	    assert(nwos_read_object_from_disk(&new_assoc_obj.header.common.id, &assoc_obj, sizeof(assoc_obj)));
 	    assert(memcmp(&assoc_obj, &new_assoc_obj, sizeof(assoc_obj)) == 0);
+#endif
 	}
 
     }
