@@ -27,6 +27,26 @@
 --
 --
 -- $Log: disk_usage.c,v $
+-- Revision 1.42  2009/07/12 18:17:10  jsedwards
+-- Changed variable that contain a number of blocks value to 64 bits and fixed
+-- the print statements for those variables to include 'll'.
+--
+-- Revision 1.41  2009/07/02 13:54:31  jsedwards
+-- Changed to include the new header.h file instead of the disk_io.h file to
+-- define the Disk_Header.
+--
+-- Revision 1.40  2009/04/21 12:13:33  jsedwards
+-- Fixed print statement format for 64 bit references and changed byte swap
+-- for chunk_info 64 bit references and 32 bit indexes.
+--
+-- Revision 1.39  2009/04/09 10:17:53  jsedwards
+-- Changed "used" chunk_info member to "flags_used" and added used mask.  Added
+-- total_private_chunks to main.
+--
+-- Revision 1.38  2009/04/06 14:03:54  jsedwards
+-- Merged in changes from CVS branch_0030_new_chunk_info branch, see revisions
+-- 1.24.2.1 and 1.24.2.2 below.
+--
 -- Revision 1.37  2009/04/03 13:12:13  jsedwards
 -- Added printing of which archive is being accessed and when it was formatted.
 -- Also increased the width of the block print field from 9 digits to 10 digits.
@@ -75,6 +95,15 @@
 -- Revision 1.25  2008/09/16 13:20:37  jsedwards
 -- Change to print a progress bar when not verbose instead of blocks used.
 --
+-- Revision 1.24.2.2  2008/08/16 03:28:07  jsedwards
+-- Changed to no longer subtract BIT_MAP_BLOCKS from used block calculation
+-- because the bit map itself is no longer included in the bit map.  Also
+-- fixed for new Disk_Header with total_chunks instead of total_blocks.
+--
+-- Revision 1.24.2.1  2008/08/11 13:52:09  jsedwards
+-- Changed to access and swap new 32-bit "flags_used" member of the chunk_info
+-- table instead of the old 16-bit "used" member.
+--
 -- Revision 1.24  2008/08/10 15:23:25  jsedwards
 -- Added path to "Missing magic number" and "Incorrect version in header" error
 -- messages.
@@ -204,7 +233,7 @@
 
 #include "chunk_info.h"
 #include "config.h"
-#include "disk_io.h"
+#include "header.h"
 #include "progress_bar.h"
 #include "user_config.h"
 
@@ -286,15 +315,15 @@ uint32 calculate_blocks_used(int obj_fd, uint32 start, Chunk_Info chunk_info[],
 
 	if (verbose)
 	{
-	    printf("Chunk %d  ref: %08x  index: %u  used: %u\n",
-		   i, chunk_info[i].ref, chunk_info[i].index, chunk_info[i].used);
+	    printf("Chunk %d  ref: %08llx  index: %u  used: %u\n",
+		   i, chunk_info[i].ref, chunk_info[i].index, (chunk_info[i].flags_used & CHUNK_INFO_USED_MASK));
 	}
 	else
 	{
 	    nwos_update_progress_bar((float)i / (float)num_chunks);
 	}
 
-	if ((blocks_used - BIT_MAP_BLOCKS) != chunk_info[i].used)
+	if (blocks_used != (chunk_info[i].flags_used & CHUNK_INFO_USED_MASK))
 	{
 	    if (!verbose)
 	    {
@@ -302,7 +331,7 @@ uint32 calculate_blocks_used(int obj_fd, uint32 start, Chunk_Info chunk_info[],
 	    }
 
 	    fprintf(stderr, "Error: chunk %d index %u stored count (%u) doesn't match bit map count (%u)\n",
-		    i, chunk_info[i].index, chunk_info[i].used, blocks_used - BIT_MAP_BLOCKS);
+		    i, chunk_info[i].index, (chunk_info[i].flags_used & CHUNK_INFO_USED_MASK), blocks_used);
 
 	    if (!verbose)
 	    {
@@ -353,7 +382,7 @@ void display_graph(Chunk_Info chunk_info[], uint32 num_chunks)
 
 	assert((RESERVED_PUBLIC_BLOCKS >> (32 - graph_bits)) <= segment && segment < (1 << graph_bits));
 
-	used_blocks[segment] += chunk_info[i].used;
+	used_blocks[segment] += chunk_info[i].flags_used & CHUNK_INFO_USED_MASK;
 	alloc_blocks[segment] += USABLE_BLOCKS_PER_CHUNK;
     }
 
@@ -417,17 +446,19 @@ int main(int argc, char* argv[])
     struct flock lock;
     const char* obj_file_path;
     char ref_str[128];
-    uint32 reserved_private_blocks;
-    uint32 used_private_blocks;
-    uint32 available_private_blocks;
+    uint64 used_private_blocks;
+    uint64 available_private_blocks;
     uint32 chunk_offset;
     uint32 system_blocks;
     uint32 used_blocks;    /* includes blocks used for bit maps */
-    uint32 allocated_blocks;
+    uint64 allocated_blocks;
     uint32 unallocated_blocks;
     uint32 total_blocks;
+    const uint32 used_system_chunks = 1;
+    uint32 total_chunks;
     uint32 total_private_chunks;
     uint32 used_private_chunks;
+    uint32 unallocated_chunks;
     uint8 block[FILE_BLOCK_SIZE];
     float divisor;
     char* range;
@@ -523,11 +554,13 @@ int main(int argc, char* argv[])
 	   nwos_extract_second_from_time_stamp(disk_header.last_change));
 
     /* get what the disk thinks */
-    nwos_4_uint8_to_uint32(disk_header.total_blocks, &reserved_private_blocks);
-    nwos_4_uint8_to_uint32(disk_header.used_blocks, &used_private_blocks);
+    nwos_4_uint8_to_uint32(disk_header.total_chunks, &total_chunks);
+    nwos_8_uint8_to_uint64(disk_header.used_blocks, &used_private_blocks);
     nwos_4_uint8_to_uint32(disk_header.block_offset_to_chunks, &chunk_offset);
     nwos_4_uint8_to_uint32(disk_header.used_chunks, &used_private_chunks);
 
+    total_private_chunks = total_chunks - used_system_chunks;
+
     sizeof_chunk_info = used_private_chunks * sizeof(Chunk_Info);
     chunk_info = malloc(sizeof_chunk_info);
     assert(chunk_info != NULL);
@@ -539,26 +572,22 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
-    assert(reserved_private_blocks % BLOCKS_IN_CHUNK == 0);
-
-    total_private_chunks = reserved_private_blocks / BLOCKS_IN_CHUNK;
-
     used_blocks = 0;
     for (i = 0; i < (int)used_private_chunks; i++)
     {
 #ifndef WORDS_BIGENDIAN
-	chunk_info[i].ref = byteswap_uint32(chunk_info[i].ref);
-	chunk_info[i].used = byteswap_uint16(chunk_info[i].used);
-	chunk_info[i].index = byteswap_uint16(chunk_info[i].index);
+	chunk_info[i].ref = byteswap_uint64(chunk_info[i].ref);
+	chunk_info[i].flags_used = byteswap_uint32(chunk_info[i].flags_used);
+	chunk_info[i].index = byteswap_uint32(chunk_info[i].index);
 #endif
-	used_blocks += chunk_info[i].used;
+	used_blocks += (chunk_info[i].flags_used & CHUNK_INFO_USED_MASK);
     }
 
     if (used_blocks != used_private_blocks)
     {
 	/* snprintf(log_msg, sizeof(log_msg), */
 	fprintf(stderr,
-		 "Warning: calculated sum of used blocks (%u) doesn't match stored (%u)",
+		 "Warning: calculated sum of used blocks (%u) doesn't match stored (%llu)",
 		 used_blocks, used_private_blocks);
 	/* nwos_log(log_msg); */
 	/* fprintf(stderr, "%s\n", log_msg); */
@@ -573,7 +602,7 @@ int main(int argc, char* argv[])
     close(obj_file_desc);
 
 
-    if (reserved_private_blocks < 4194304)    /* print in megabytes */
+    if (total_chunks < 64)    /* print in megabytes (64 chunks == 1 gigabyte) */
     {
 	divisor = 1048576.0f / 256.0f;
 	range = "Megabytes";
@@ -584,14 +613,16 @@ int main(int argc, char* argv[])
 	range = "Gigabytes";
     }
 
-    available_private_blocks = reserved_private_blocks - used_private_blocks;
+    available_private_blocks = ((total_chunks - used_system_chunks) * USABLE_BLOCKS_PER_CHUNK) - used_private_blocks;
 
-    system_blocks = BLOCKS_IN_CHUNK + total_private_chunks * BIT_MAP_BLOCKS;
+    system_blocks = BLOCKS_IN_CHUNK + (total_private_chunks - used_system_chunks) * BIT_MAP_BLOCKS;
 
     allocated_blocks = used_private_chunks * USABLE_BLOCKS_PER_CHUNK;
-    unallocated_blocks = (total_private_chunks - used_private_chunks) * USABLE_BLOCKS_PER_CHUNK,
 
-    total_blocks = reserved_private_blocks + BLOCKS_IN_CHUNK;
+    unallocated_chunks = total_chunks - used_system_chunks - used_private_chunks;
+    unallocated_blocks = unallocated_chunks * USABLE_BLOCKS_PER_CHUNK;
+
+    total_blocks = total_chunks * BLOCKS_IN_CHUNK;
 
     printf("\n");
 
@@ -611,17 +642,17 @@ int main(int argc, char* argv[])
 
     printf("Allocated:     %5u\n", used_private_chunks);
 
-    printf("  Used:               %10u    %5.1f  %5.1f%%\n",
+    printf("  Used:               %10llu    %5.1f  %5.1f%%\n",
 	   used_private_blocks,
 	   (float)used_private_blocks / divisor,
 	   100.0f * (float)used_private_blocks / (float)total_blocks);
 
-    printf("  Free:               %10u    %5.1f  %5.1f%%\n",
+    printf("  Free:               %10llu    %5.1f  %5.1f%%\n",
 	   allocated_blocks - used_private_blocks,
 	   (float)(allocated_blocks - used_private_blocks) / divisor,
 	   100.0f * (float)(allocated_blocks - used_private_blocks) / (float)total_blocks);
 
-    printf("  Total:              %10u    %5.1f  %5.1f%%\n",
+    printf("  Total:              %10llu    %5.1f  %5.1f%%\n",
 	   allocated_blocks,
 	   (float)allocated_blocks / divisor,
 	   100.0f * (float)allocated_blocks / (float)total_blocks);
