@@ -1,6 +1,6 @@
 /*
 --             This file is part of the New World OS project
---                 Copyright (C) 2005-2008  QRW Software
+--                 Copyright (C) 2005-2009  QRW Software
 --           J. Scott Edwards - j.scott.edwards.nwos@gmail.com 
 --                      http://www.qrwsoftware.com
 --                      http://nwos.sourceforge.com
@@ -27,6 +27,18 @@
 --
 --
 -- $Log: dump_obj.c,v $
+-- Revision 1.23  2009/03/14 19:14:21  jsedwards
+-- Added include of security.h file, renamed read_object_and_decrypt functions
+-- to read_block_and_decrypt, and changed parameters to just pass sequence
+-- number.
+--
+-- Revision 1.22  2009/03/13 12:31:18  jsedwards
+-- Added include of objectify.h file and added comment about needing disk_io.h
+-- just for IVEC_SIZE.
+--
+-- Revision 1.21  2009/03/08 00:06:18  jsedwards
+-- Changed include objectify_private.h to disk_io.h.
+--
 -- Revision 1.20  2008/09/01 03:13:41  jsedwards
 -- Change for new nwos_initialize_objectify calling convention (doesn't pass
 -- back root_object_reference anymore) and removed call to nwos_set_root_object
@@ -108,8 +120,10 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "objectify_private.h"
 #include "crc32.h"
+#include "disk_io.h"       /* define IVEC_SIZE */
+#include "objectify.h"
+#include "security.h"
 
 
 #define SIZE_EXTRA_BLOCK_DATA (FILE_BLOCK_SIZE - sizeof(uint32) - sizeof(ObjRef) - sizeof(ObjRef))
@@ -191,7 +205,7 @@ int main(int argc, char* argv[])
 
     memset(ivec, 0, sizeof(ivec));
 
-    if (!nwos_read_object_from_disk_and_decrypt(&ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]))
+    if (!nwos_read_block_from_disk_and_decrypt(&ref, &extra, sizeof(extra), ivec, seq))
     {
 	fprintf(stderr, "Error: nwos_read_object_from_disk_and_decrypt failed\n");
 	exit(1);
@@ -207,7 +221,7 @@ int main(int argc, char* argv[])
 
 	memset(ivec, 0, sizeof(ivec));
 
-	if (!nwos_read_object_from_disk_and_old_decrypt(&ref, &extra, sizeof(extra), ivec, nwos_random_sequence[seq]))
+	if (!nwos_read_block_from_disk_and_old_decrypt(&ref, &extra, sizeof(extra), ivec, seq))
 	{
 	    fprintf(stderr, "Error: nwos_read_object_from_disk_and_old_decrypt failed\n");
 	    exit(1);
