@@ -27,9 +27,44 @@
 --
 --
 -- $Log: expand_sparse.c,v $
+-- Revision 1.50  2009/07/18 15:45:08  jsedwards
+-- Add a hack to scan the compressed file, if it is a 0029 or older, and count
+-- the number of chunks needed for it.  This is necessary because the chunk
+-- count can be different between versions 0029 and 0030.
+--
+-- Revision 1.49  2009/07/18 15:36:54  jsedwards
+-- Changed num_blocks variable to 64-bit unsigned instead of integer so that
+-- it matches the used_private_blocks variable.
+--
+-- Revision 1.48  2009/07/12 01:53:46  jsedwards
+-- Changed used_private_blocks to 64 bits, fixed to expand 32 bit used blocks
+-- if old header, and added 'll' to print format when printing number of blocks.
+--
+-- Revision 1.47  2009/07/05 00:48:15  jsedwards
+-- Added include of the disk_io.h file.
+--
+-- Revision 1.46  2009/06/13 12:53:14  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.40.2.1  2009/06/06 13:51:11  jsedwards
 -- Fix Bug #2740516 - Changed to check return value from fgets.
 --
+-- Revision 1.45  2009/04/14 12:32:17  jsedwards
+-- Changed to call new terminate_storage function instead of terminate_disk_io.
+--
+-- Revision 1.44  2009/04/14 11:59:38  jsedwards
+-- Changed to call new initialize_storage function instead of initialize_disk_io.
+--
+-- Revision 1.43  2009/04/11 21:22:17  jsedwards
+-- Added include for the chunk_info.h file.
+--
+-- Revision 1.42  2009/04/09 10:31:27  jsedwards
+-- Changed to calculate total private blocks from nwos_total_private_chunks.
+--
+-- Revision 1.41  2009/04/06 14:25:24  jsedwards
+-- Merged in changes from CVS branch_0030_new_chunk_info branch, see revision
+-- 1.31.2.1 below.
+--
 -- Revision 1.40  2009/03/14 23:06:41  jsedwards
 -- Added include of the new backup.h file.
 --
@@ -60,6 +95,10 @@
 -- Revision 1.32  2008/08/30 12:56:13  jsedwards
 -- Changed parameters for nwos_initialize_objectify call.
 --
+-- Revision 1.31.2.1  2008/08/16 02:32:06  jsedwards
+-- Removed reference to total_blocks in Disk_Header since it was changed in
+-- version 0030 to total_chunks and was only used for printing in this program.
+--
 -- Revision 1.31  2008/07/19 13:15:33  jsedwards
 -- If 0'd out printing of every block's reference ID so it doesn't spew every
 -- block ID to the screen anymore.  Added calls to print a progress bar instead.
@@ -213,11 +252,13 @@
 
 #include "backup.h"
 #include "bit_map.h"
+#include "chunk_info.h"
 #include "config.h"
 #include "disk_io.h"
 #include "gen_id.h"
 #include "log.h"
 #include "progress_bar.h"
+#include "storage.h"
 #include "user_config.h"
 
 
@@ -235,12 +276,13 @@ int main(int argc, char* argv[])
     FILE* ifp;
     uint32 ref;
     uint32 hash;
-    int num_blocks = 0;
-    uint32 total_private_blocks;
-    uint32 used_private_blocks;
+    uint64 num_blocks;
+    uint64 used_private_blocks;
+    uint32 used_private_blocks_32_bits;
     uint32 used_private_chunks;
-    uint32 num_chunks;
+    uint32 chunk_count;
     Disk_Header compressed_header;
+    Disk_Header_0022_to_0029 old_header;
 #if 0
     Disk_Header_0021 old_header;
 #endif
@@ -266,7 +308,7 @@ int main(int argc, char* argv[])
 
     obj_file_path = nwos_get_private_objects_path();
 
-    nwos_initialize_disk_io(READ_WRITE, DEFAULT_FILE);
+    nwos_initialize_storage(READ_WRITE, DEFAULT_FILE);
 
     nwos_terminate_backup(false, NULL);   /* don't create a backup file */
 
@@ -328,12 +370,11 @@ int main(int argc, char* argv[])
 
 
     /* verify that the number of used blocks is consistent with empty disk */
-    num_chunks = (nwos_total_private_blocks + BLOCKS_IN_CHUNK - 1) / BLOCKS_IN_CHUNK; /* round up */
 
     if (nwos_used_private_blocks != 0 || nwos_used_private_chunks != 0)
     {
-	fprintf(stderr, "ERROR: disk not empty, chunks used: %u  blocks used: %u!.\n", 
-		nwos_used_private_blocks, nwos_used_private_chunks);
+	fprintf(stderr, "ERROR: disk not empty, chunks used: %u  blocks used: %llu!.\n", 
+		nwos_used_private_chunks, nwos_used_private_blocks);
 	exit(1);
     }
 
@@ -368,27 +409,94 @@ int main(int argc, char* argv[])
 	/* if old versions need special handling put it here and remove braces below */ 
 
 	if (memcmp(&block[4], "0028", 4) < 0) pre_0028 = true;   /* need to warn at the end */
+
+	memcpy(&old_header, block, sizeof(old_header));
+
+	nwos_4_uint8_to_uint32(old_header.used_blocks, &used_private_blocks_32_bits);
+	nwos_4_uint8_to_uint32(old_header.used_chunks, &used_private_chunks);
+
+	used_private_blocks = used_private_blocks_32_bits;
+
+	if (memcmp(&block[4], "0030", 4) < 0)    /* if 0029 version or less the chunk count may be differen */
+	{
+	    fprintf(stderr, "WARNING: number of chunks may change between pre-0030 versions and post-0029\n");
+	    fprintf(stderr, "         versions.  Scanning compressed file to determine number of chunks\n");
+	    fprintf(stderr, "         needed to expand this compressed file.\n");
+
+	    bytes_read = fread(block, 1, FILE_BLOCK_SIZE, ifp);
+
+	    nwos_start_progress_bar();
+
+	    num_blocks = 0;
+	    hash = 0;
+	    chunk_count = 0;
+
+	    while (bytes_read == FILE_BLOCK_SIZE)
+	    {
+		nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
+
+		nwos_4_uint8_to_uint32(&block[4], &ref);
+
+		/* Yes this is a hack!  The new chunks are exactly 65536 blocks so we just have to compare */
+		/* the upper 16 bits of the reference to deterimine if the blocks are in different chunks. */
+		if ((hash & 0xffff0000) != (ref & 0xffff0000))
+		{
+		    chunk_count++;
+		    hash = ref;
+		}
+
+		num_blocks++;
+
+		bytes_read = fread(block, 1, FILE_BLOCK_SIZE, ifp);
+	    }
+
+	    nwos_finish_progress_bar();
+
+	    if (ferror(ifp))
+	    {
+		perror(argv[1]);
+		exit(1);
+	    }
+
+	    if (num_blocks != used_private_blocks)
+	    {
+		printf("ERROR: blocks in file (%llu) is does not match number of used private blocks in header (%llu)\n", num_blocks, used_private_blocks);
+		exit(1);
+	    }
+
+	    fprintf(stderr, "chunks in old header: %u  chunks required now: %u\n", used_private_chunks, chunk_count);
+
+	    if (used_private_chunks < chunk_count)
+	    {
+		used_private_chunks = chunk_count;
+	    }
+
+	    if (fseek(ifp, FILE_BLOCK_SIZE, SEEK_SET) != 0)
+	    {
+		perror(argv[1]);
+		exit(1);
+	    }
+	}
     }
     else
     {
 	printf("compressed file version: %c%c%c%c\n", block[4], block[5], block[6], block[7]);
 	sleep(5);
-
+#if 0
     }  /* remove these two braces if the the blocks and chunks */
     {  /* need to be read differently for the old file format */ 
-
+#endif
 	memcpy(&compressed_header, block, sizeof(compressed_header));
 
-	nwos_4_uint8_to_uint32(compressed_header.total_blocks, &total_private_blocks);
-	nwos_4_uint8_to_uint32(compressed_header.used_blocks, &used_private_blocks);
+	nwos_8_uint8_to_uint64(compressed_header.used_blocks, &used_private_blocks);
 	nwos_4_uint8_to_uint32(compressed_header.used_chunks, &used_private_chunks);
 
     }
 
     if (nwos_archive_is_block_device())
     {
-	printf("   total_private_blocks: %u  used_private_blocks: %u\n",
-	       total_private_blocks, used_private_blocks);
+	printf("   total_private_blocks: %u  used_private_blocks: %llu\n",
+	       nwos_total_private_chunks * USABLE_BLOCKS_PER_CHUNK, used_private_blocks);
 
 	if (used_private_chunks > nwos_total_private_chunks)
 	{
@@ -422,6 +530,8 @@ int main(int argc, char* argv[])
 
     nwos_start_progress_bar();
 
+    num_blocks = 0;
+
     while (bytes_read == FILE_BLOCK_SIZE)
     {
 	nwos_update_progress_bar((float)num_blocks / (float)used_private_blocks);
@@ -476,16 +586,15 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
-    nwos_terminate_disk_io();
+    nwos_terminate_storage();
 
-    snprintf(msg, sizeof(msg), "Number of blocks written: %d  chunks_used: %u",
-	     num_blocks, nwos_used_private_chunks);
+    snprintf(msg, sizeof(msg), "Number of blocks written: %llu  chunks_used: %u", num_blocks, nwos_used_private_chunks);
     nwos_log(msg);
     printf("%s\n", msg);
 
     if (used_private_blocks != nwos_used_private_blocks)
     {
-	snprintf(msg, sizeof(msg), "WARNING: used_private_blocks mismatch, disk: %u  compressed %u\n",
+	snprintf(msg, sizeof(msg), "WARNING: used_private_blocks mismatch, disk: %llu  compressed %llu\n",
 		nwos_used_private_blocks, used_private_blocks);
 	fprintf(stderr, "%s\n", msg);
     }
