@@ -27,6 +27,19 @@
 --
 --
 -- $Log: financial.c,v $
+-- Revision 1.13  2009/07/19 13:41:22  jsedwards
+-- Added ifdef VERIFY_WRITE around more code that reads back objects to verify
+-- they were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
+-- Revision 1.12  2009/07/19 13:21:44  jsedwards
+-- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
+-- were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
+-- Revision 1.11  2009/06/13 11:37:25  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.10.2.1  2009/06/06 14:03:54  jsedwards
 -- Moved get_input function to new dialog.c file, renamed it to nwos_ask_user,
 -- and changed to call it.
@@ -441,6 +454,7 @@ ObjCreateResult nwos_find_or_create_account_number(char* number, ObjRef* ref)
 
 	nwos_add_to_references(ref, &number_class_ref);
 
+#ifdef VERIFY_WRITE
 	ptr_number_obj = malloc(sizeof(C_struct_Account_Number) + length);
 	assert(nwos_read_object_from_disk(ref, ptr_number_obj, sizeof(C_struct_Account_Number) + length));
 	assert(memcmp(kludge, ptr_number_obj, sizeof(C_struct_Account_Number) + length) == 0);
@@ -451,6 +465,7 @@ ObjCreateResult nwos_find_or_create_account_number(char* number, ObjRef* ref)
 
 	free(ptr_number_obj);
 	ptr_number_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
@@ -526,7 +541,9 @@ void nwos_create_account(ObjRef* credit_union_ref, ObjRef* account_num_ref, ObjR
 {
     ObjRef account_class_ref;
     C_struct_Account account_obj;
+#ifdef VERIFY_WRITE
     C_struct_Account test_obj;
+#endif
 
     assert(!nwos_find_account(credit_union_ref, account_num_ref, ref));
 
@@ -554,8 +571,10 @@ void nwos_create_account(ObjRef* credit_union_ref, ObjRef* account_num_ref, ObjR
     nwos_add_to_references(ref, &account_obj.institution);
     nwos_add_to_references(ref, &account_obj.number);
 
+#ifdef VERIFY_WRITE
     assert(nwos_read_object_from_disk(ref, &test_obj, sizeof(C_struct_Account)));
     assert(memcmp(&account_obj, &test_obj, sizeof(C_struct_Account)) == 0);
+#endif
 }
 
 
@@ -598,6 +617,7 @@ void nwos_create_checking(ObjRef* account_ref, char* id, ObjRef* ref)
 
     nwos_add_to_references(ref, &ptr_checking_obj->account);
 
+#ifdef VERIFY_WRITE
     ptr_checking_obj = malloc(sizeof(C_struct_Checking) + length);
     assert(nwos_read_object_from_disk(ref, ptr_checking_obj, sizeof(C_struct_Checking) + length));
     assert(memcmp(kludge, ptr_checking_obj, sizeof(C_struct_Checking) + length) == 0);
@@ -608,6 +628,7 @@ void nwos_create_checking(ObjRef* account_ref, char* id, ObjRef* ref)
 
     free(ptr_checking_obj);
     ptr_checking_obj = NULL;
+#endif
 }
 
 
