@@ -27,6 +27,20 @@
 --
 --
 -- $Log: gen_id.c,v $
+-- Revision 1.28  2009/07/18 02:16:38  jsedwards
+-- Changed functions that reference the chunk_info.ref to 64 bit values.
+--
+-- Revision 1.27  2009/07/12 01:24:00  jsedwards
+-- Changed total blocks from uint32 to uint64, deleted assert that checked
+-- total chunks and total blocks correlated, and fixed print statements.
+--
+-- Revision 1.26  2009/06/13 15:35:22  jsedwards
+-- Changed to call new chunk_is_full and blocks_used_in_chunk functions instead
+-- of accessing chunk_info directly.
+--
+-- Revision 1.25  2009/06/13 13:00:20  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.18.2.6  2009/06/09 12:39:19  jsedwards
 -- Changed to only create a new chunk island at random.
 --
@@ -49,6 +63,30 @@
 -- Revision 1.18.2.1  2009/05/18 12:28:15  jsedwards
 -- Fixed to compile correctly in PUBLIC MODE.
 --
+-- Revision 1.24  2009/05/09 16:50:09  jsedwards
+-- Changed to call new nwos_blocks_used_in_chunk and nwos_chunk_is_full
+-- functions instead of accessing chunk_info table directly.
+--
+-- Revision 1.23  2009/04/19 09:04:23  jsedwards
+-- Moved nwos_hash_uint32_ref, nwos_hash_ref, and nwos_ref_to_offset functions
+-- to chunk_info.c file.
+--
+-- Revision 1.22  2009/04/13 12:51:13  jsedwards
+-- Moved nwos_read_block, nwos_write_block, and nwos_erase_block functions to
+-- new storage.c file.
+--
+-- Revision 1.21  2009/04/12 00:40:06  jsedwards
+-- Moved the nwos_read_block, nwos_write_block, and nwos_erase_block functions
+-- from the disk_io.c file.
+--
+-- Revision 1.20  2009/04/11 21:20:10  jsedwards
+-- Moved the RESERVED_PRIVATE_CHUNKS define (which currently isn't used) from
+-- the disk_io.h file.
+--
+-- Revision 1.19  2009/04/07 14:51:38  jsedwards
+-- Merged in changes from disk_io.c file in CVS
+-- branch_0030_new_chunk_info branch, see revision 1.89.2.1 in disk_io.c file.
+--
 -- Revision 1.18  2009/04/04 13:18:11  jsedwards
 -- Moved code from nwos_check_blocks_available and created new
 -- find_starting_chunk_for_blocks function and then called it in several
@@ -130,8 +168,10 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>      /* define memset */
 #include <time.h>
 
+#include "backup.h"
 #include "bit_map.h"
 #include "chunk_info.h"
 #include "disk_io.h"
@@ -139,6 +179,11 @@
 #include "log.h"
 
 
+/* some blocks don't come out even when dividing usable chunks per block, so don't allocate them */
+
+#define RESERVED_PRIVATE_CHUNKS (RESERVED_PRIVATE_BLOCKS / USABLE_BLOCKS_PER_CHUNK)
+/*                              (0xeff00000              / 65504)    = 61454 */
+
 ObjRef nwos_next_public_ref;
 
 #ifndef PUBLIC_MODE
@@ -221,74 +266,6 @@ void nwos_terminate_gen_id(void)
 
 
 
-/*********************************************************************************************/
-/* this function maps a uint32 reference to a block number                                   */
-/*                                                                                           */
-/* The new formula is to skip over the bit maps instead of leaving holes for them, so every  */
-/* 32 bit number is available for use.                                                       */
-/*********************************************************************************************/
-
-uint32 nwos_hash_uint32_ref(uint32 ref)
-{
-#ifdef PUBLIC_MODE
-    assert(ref < nwos_used_public_blocks);
-    return ref;
-#else
-    int index;
-    uint32 result = 0;
-    uint32 chunk;
-    uint32 offset;
-
-    if (ref <= MAXIMUM_PUBLIC_REFERENCE)
-    {
-	result = ref;
-    }
-    else if (ref <= MAXIMUM_PRIVATE_REFERENCE && nwos_used_private_chunks > 0)
-    {
-	index = nwos_uint32_ref_to_info_index(ref);
-
-	if (index >= 0)    /* found it */
-	{
-	    chunk = (uint32) nwos_chunk_info[index].index;
-
-	    offset = (ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK;
-
-	    result = nwos_block_offset_to_chunks + (chunk * BLOCKS_IN_CHUNK) + BIT_MAP_BLOCKS + offset;
-	}
-
-//	printf("total blocks: %u chunks: %u  chunk: %u  offset: %u  result: %u (%08x)\n",
-//	       nwos_total_private_blocks, nwos_total_private_chunks, chunk, offset, result, result);
-    }
-
-    return result;
-#endif
-}
-
-
-uint32 nwos_hash_ref(ObjRef* ref)
-{
-    uint32 uint32_ref;
-
-    uint32_ref = ((uint32)(ref->id[0]) << 24) | ((uint32)(ref->id[1]) << 16) | 
-                                  ((uint32)(ref->id[2]) << 8) | ((uint32)(ref->id[3]));
-
-    return nwos_hash_uint32_ref(uint32_ref);
-}
-
-
-off_t nwos_ref_to_offset(ObjRef* ref)
-{
-    uint32 hash;
-
-    assert(FILE_BLOCK_SIZE == 256);
-
-    hash = nwos_hash_ref(ref);
-
-    return hash == 0 ? (off_t) -1 : (off_t) hash << 8;
-}
-
-
-
 #ifndef PUBLIC_MODE
 
 #ifdef CHANGE_SECURITY_TO_DENSITY
@@ -366,13 +343,13 @@ static uint32 blocks_in_contiguous_chunks(int info_index, uint32 maximum_chunks)
 
     if (max_index > nwos_used_private_chunks) max_index = nwos_used_private_chunks;
 
-    result = USABLE_BLOCKS_PER_CHUNK - nwos_chunk_info[info_index].used;
+    result = USABLE_BLOCKS_PER_CHUNK - nwos_blocks_used_in_chunk(info_index);
 
     for (i = info_index + 1; i < max_index; i++)
     {
 	if (nwos_chunk_info[i-1].ref + USABLE_BLOCKS_PER_CHUNK != nwos_chunk_info[i].ref) break;  /* not contiguous */
 
-	result += USABLE_BLOCKS_PER_CHUNK - nwos_chunk_info[i].used;
+	result += USABLE_BLOCKS_PER_CHUNK - nwos_blocks_used_in_chunk(i);
     }
 
     return result;
@@ -457,13 +434,13 @@ static int find_smallest_chunk_island(void)
 
 static uint32 find_new_random_chunk_location(uint32 needed_chunks)
 {
-    uint32 lower_ref;
-    uint32 upper_ref;
+    uint64 lower_ref;
+    uint64 upper_ref;
     uint32 num_chunks;
     uint32 ref = 0;
     int i;
 
-    lower_ref = MINIMUM_PRIVATE_REFERENCE;
+    lower_ref = MINIMUM_32_BIT_PRIVATE_REFERENCE;
     upper_ref = nwos_chunk_info[0].ref;
 
     for (i = 1; i < nwos_used_private_chunks; i++)
@@ -478,14 +455,14 @@ static uint32 find_new_random_chunk_location(uint32 needed_chunks)
 	}
     }
 
-    if (MAXIMUM_PRIVATE_REFERENCE + 1 - nwos_chunk_info[i-1].ref > upper_ref - lower_ref)
+    if (MAXIMUM_32_BIT_PRIVATE_REFERENCE + 1 - nwos_chunk_info[i-1].ref > upper_ref - lower_ref)
     {
 	lower_ref = nwos_chunk_info[i-1].ref;
-	upper_ref = MAXIMUM_PRIVATE_REFERENCE + 1;
+	upper_ref = MAXIMUM_32_BIT_PRIVATE_REFERENCE + 1;
     }
 
-    assert((lower_ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
-    assert((upper_ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+    assert((lower_ref - MINIMUM_32_BIT_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+    assert((upper_ref - MINIMUM_32_BIT_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
 
     num_chunks = (upper_ref - lower_ref) / USABLE_BLOCKS_PER_CHUNK;
 
@@ -493,16 +470,16 @@ static uint32 find_new_random_chunk_location(uint32 needed_chunks)
     {
 	ref = lower_ref + (random() % (num_chunks - needed_chunks)) * USABLE_BLOCKS_PER_CHUNK;
 
-	assert((ref - MINIMUM_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
+	assert((ref - MINIMUM_32_BIT_PRIVATE_REFERENCE) % USABLE_BLOCKS_PER_CHUNK == 0);
     }
 
-    return ref;
+    return (uint32) (ref - BASE_32_BIT_PRIVATE);
 }
 
 
 bool nwos_check_blocks_available(uint32 estimated_blocks)
 {
-    uint32 total_blocks;
+    uint64 total_blocks;
     uint32 needed_blocks;
     uint32 needed_chunks;
     uint32 allocated_blocks;
@@ -524,7 +501,6 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
     assert(1 <= chunk_density_target && chunk_density_target <= USABLE_BLOCKS_PER_CHUNK);
     assert(1 <= chunk_skip_forward && chunk_skip_forward <= RESERVED_PRIVATE_CHUNKS);
 #endif
-    assert(nwos_total_private_blocks == nwos_total_private_chunks * BLOCKS_IN_CHUNK);
 
     if (block_estimate > 0)   /* there was a previous estimate */
     {
@@ -569,9 +545,9 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 	{
 	    fprintf(stderr, "\n");
 	    fprintf(stderr, "Archive is too full:\n");
-	    fprintf(stderr, "      Total blocks: %u\n", total_blocks);
-	    fprintf(stderr, "       Used blocks: %u\n", nwos_used_private_blocks);
-	    fprintf(stderr, "  Available blocks: %u\n", total_blocks - nwos_used_private_blocks);
+	    fprintf(stderr, "      Total blocks: %llu\n", total_blocks);
+	    fprintf(stderr, "       Used blocks: %llu\n", nwos_used_private_blocks);
+	    fprintf(stderr, "  Available blocks: %llu\n", total_blocks - nwos_used_private_blocks);
 	    fprintf(stderr, "  Estimated blocks: %u\n", estimated_blocks);
 	    fprintf(stderr, "\n");
 
@@ -595,7 +571,7 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 	assert(nwos_used_private_chunks < nwos_total_private_chunks);
 
 	/* temporary hack to handle the situation where we have reached the end of the private chunks */
-	if (nwos_chunk_info[nwos_used_private_chunks-1].ref + USABLE_BLOCKS_PER_CHUNK > MAXIMUM_PRIVATE_REFERENCE)
+	if (nwos_chunk_info[nwos_used_private_chunks-1].ref + USABLE_BLOCKS_PER_CHUNK > MAXIMUM_32_BIT_PRIVATE_REFERENCE)
 	{
 	    snprintf(msg, sizeof(msg), "WARNING: reached the end of private space, working backwards.");
 	    nwos_log(msg);
@@ -615,13 +591,13 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 	}
 	else if (chunk_skip_forward == RESERVED_PRIVATE_CHUNKS)
 	{
-	    max = MAXIMUM_PRIVATE_REFERENCE - nwos_chunk_info[nwos_used_private_chunks-1].ref;
+	    max = MAXIMUM_32_BIT_PRIVATE_REFERENCE - nwos_chunk_info[nwos_used_private_chunks-1].ref;
 	    skip = 1 + random() % (max / USABLE_BLOCKS_PER_CHUNK);
 	    ref = nwos_chunk_info[nwos_used_private_chunks-1].ref + (USABLE_BLOCKS_PER_CHUNK * skip);
 	}
 	else
 	{
-	    max = (MAXIMUM_PRIVATE_REFERENCE - nwos_chunk_info[nwos_used_private_chunks-1].ref) / USABLE_BLOCKS_PER_CHUNK;
+	    max = (MAXIMUM_32_BIT_PRIVATE_REFERENCE - nwos_chunk_info[nwos_used_private_chunks-1].ref) / USABLE_BLOCKS_PER_CHUNK;
 	    if (max > chunk_skip_forward) max = chunk_skip_forward;
 	    skip = 1 + random() % max;
 	    ref = nwos_chunk_info[nwos_used_private_chunks-1].ref + (USABLE_BLOCKS_PER_CHUNK * skip);
@@ -670,7 +646,7 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 
 		for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)    /* let the pieces fall where they may */
 		{
-		    if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+		    if (!nwos_chunk_is_full(info_index)) break;
 		}
 	    }
 	    else   /* make more room */
@@ -722,7 +698,7 @@ bool nwos_check_blocks_available(uint32 estimated_blocks)
 	}
     }
 
-    if (block_estimate < 5 && nwos_chunk_info[info_index].used < 5)       /* allow random location for root objects */
+    if (block_estimate < 5 && nwos_blocks_used_in_chunk(info_index) < 5)       /* allow random location for root objects */
     {
 	offset = random() % (USABLE_BLOCKS_PER_CHUNK - 5);
 	nwos_word_to_ref(nwos_chunk_info[info_index].ref + offset, &last_ref);
@@ -793,19 +769,19 @@ static void generate_new_completely_random_id(ObjRef* ref)
 	{
 	    info_index = random() % nwos_used_private_chunks;
 
-	    if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+	    if (!nwos_chunk_is_full(chunk)) break;
 	}
 
 	if (i == nwos_used_private_chunks)   /* didn't find one, just do a search */
 	{
 	    for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)
 	    {
-		if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+		if (!nwos_chunk_is_full(chunk)) break;
 	    }
 	}
     }
 
-    assert(nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK);
+    assert(!nwos_chunk_is_full(chunk));
 
     word = nwos_find_random_block_in_chunk(info_index);
 
@@ -875,7 +851,7 @@ static void nwos_generate_new_closely_spaced_id(int density, ObjRef* new_ref)
 
 	    info_index = nwos_chunk_index_to_info_index(chunk_index);
 
-	    while (nwos_chunk_info[info_index].used > max_used)
+	    while (nwos_blocks_used_in_chunk(info_index) > max_used)
 	    {
 		/* see if the chunk after this one is usable, and if so back into this chunk */
 		if (info_index + 1 == nwos_total_private_chunks)
@@ -884,7 +860,7 @@ static void nwos_generate_new_closely_spaced_id(int density, ObjRef* new_ref)
 		    bool need_to_fix_allocation_code = false;
 		    assert(need_to_fix_allocation_code);
 		}
-		else if (nwos_chunk_info[info_index + 1].used <= max_used)
+		else if (nwos_blocks_used_in_chunk(info_index + 1) <= max_used)
 		{
 		    byte_num = nwos_find_low_density_in_chunk(info_index, density);
 
@@ -1013,7 +989,7 @@ void nwos_generate_new_private_id(ObjRef* new_ref)
 
 	    for (info_index = 0; info_index < nwos_used_private_chunks; info_index++)
 	    {
-		if (nwos_chunk_info[info_index].used < USABLE_BLOCKS_PER_CHUNK) break;
+		if (!nwos_chunk_is_full(info_index)) break;
 	    }
 
 	    ref = nwos_chunk_info[info_index].ref;
@@ -1106,3 +1082,4 @@ void nwos_generate_new_id(ObjRef* ref)
     assert(nwos_reference_type(ref) == Private_Reference);
 #endif
 
+
