@@ -27,6 +27,17 @@
 --
 --
 -- $Log: list_files.c,v $
+-- Revision 1.39  2009/03/10 04:15:05  jsedwards
+-- Eliminated the use of FILE_BLOCK_SIZE for kludge buffers.
+--
+-- Revision 1.38  2009/03/08 01:01:51  jsedwards
+-- Changed include objectify_private.h to objectify.h and changed test to verify
+-- that public files were found to an assert because the public objects have had
+-- files in them for over a year now and so it should never fail if we have the
+-- current public objects.  This way we don't have to include disk_io.h.  Also
+-- changed to call new nwos_archive_version function instead of accessing the
+-- header directly.
+--
 -- Revision 1.37  2009/01/26 16:32:52  jsedwards
 -- Changed to use PATH_MAX for size of name buffer instead of 256.
 --
@@ -181,7 +192,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include "objectify_private.h"   /* do private so that nwos_get_public_objects_path is defined */
+#include "objectify.h"
 #include "time_stamp.h"
 
 
@@ -306,7 +317,7 @@ int main(int argc, char* argv[])
     C_struct_Path_And_File_Association assoc_obj;
     C_struct_Path_And_File_Association prev_assoc_obj;
     C_struct_Path_And_File_Association next_assoc_obj;
-    uint8 kludge[FILE_BLOCK_SIZE];
+    uint8 kludge[MAX_PATH_OBJ_SIZE];
     C_struct_File_Path* ptr_path_obj = (C_struct_File_Path*)kludge;
     C_struct_File file_obj;
     ObjRef object_class;
@@ -430,11 +441,7 @@ int main(int argc, char* argv[])
     {
 	nwos_initialize_objectify(PUBLIC, NULL);
 
-	if (!nwos_find_public_class_definition("PATH AND FILE ASSOCIATION", &assoc_class_ref))
-	{
-	    printf("No public files found, please update your Public Objects file: %s!\n", nwos_get_public_objects_path());
-	    exit(1);
-	}
+	assert(nwos_find_public_class_definition("PATH AND FILE ASSOCIATION", &assoc_class_ref));
     }
     else
     {
@@ -635,7 +642,7 @@ int main(int argc, char* argv[])
 	    fprintf(stderr, "         Alpha_28).  You should run the program: update_files_0028 on this\n");
 	    fprintf(stderr, "         archive to update them to the current method.\n");
 	}
-	else if (memcmp(nwos_disk_header.version_string, "0028", 4) < 0)    /* reading from old compressed file */
+	else if (memcmp(nwos_archive_version(), "0028", 4) < 0)    /* reading from old compressed file */
 	{
 	    fprintf(stderr, "NOTE: the %d files with an asterisk (*) following the revision number used\n",
 		    old_file_revisions);
