@@ -27,6 +27,17 @@
 --
 --
 -- $Log: objectify.c,v $
+-- Revision 1.202  2009/06/30 11:14:45  jsedwards
+-- Added include of new header.h file and moved nwos_archive_version function
+-- from the disk_io.c file.
+--
+-- Revision 1.201  2009/06/13 15:31:45  jsedwards
+-- Added include of disk_io.h to define stuff to write empty chunk for create
+-- root when archive is a file, needed for add_password.
+--
+-- Revision 1.200  2009/06/13 12:53:14  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.195.2.4  2009/06/07 15:08:16  jsedwards
 -- Fix Bug #2802374 - change to allocate a new chunk if the archive is a file.
 --
@@ -38,7 +49,22 @@
 -- it needs to be called in public mode too.
 --
 -- Revision 1.195.2.1  2009/05/18 12:38:49  jsedwards
--- Changed so nwos_remove_object is not compiled in public mode.
+-- Changed so nwos_remove_object is not compiled in public mode.  (Note: in the
+-- main trunk nwos_remove_object was moved to the objects.c file, so this change
+-- was made there in the main trunk.)
+--
+-- Revision 1.199  2009/04/19 14:20:05  jsedwards
+-- Added include of chunk_info.h file to define nwos_hash_ref.
+--
+-- Revision 1.198  2009/04/14 11:51:10  jsedwards
+-- Moved external declarations for update file functions to objects.c file.
+--
+-- Revision 1.197  2009/04/13 13:37:47  jsedwards
+-- Moved object related functions to new objects.c file.
+--
+-- Revision 1.196  2009/04/10 14:20:58  jsedwards
+-- Added nwos_flush_to_disk function that flushes any dirty reference lists
+-- and then flushes the disk io.
 --
 -- Revision 1.195  2009/04/01 14:44:59  jsedwards
 -- Added call to check blocks available in create root so that last_ref is set.
@@ -1033,11 +1059,14 @@
 #include <unistd.h>
 
 #include "bit_map.h"
+#include "chunk_info.h"                /* define nwos_hash_ref */
 #include "class_definition.h"
 #include "crc32.h"
-#include "disk_io.h"
+#include "disk_io.h"                   /* define nwos_archive_is_file and nwos_write_empty_chunk */
+#include "header.h"
 #include "objectify.h"
 #include "security.h"
+#include "storage.h"
 #include "time_stamp.h"
 
 
@@ -1049,10 +1078,6 @@
 bool verbose = false;
 bool nwos_ready = false;
 
-/* Defined in file.c, not for general usage */
-
-extern void nwos_update_file_001_object_to_current(void* object, size_t size);
-extern void nwos_update_file_002_object_to_current(void* object, size_t size);
 
 
 bool nwos_is_ready(void)
@@ -1062,7 +1087,7 @@ bool nwos_is_ready(void)
 
 bool nwos_is_writable(void)
 {
-    return nwos_disk_io_is_read_write();
+    return nwos_storage_is_read_write();
 }
 
 
@@ -1175,7 +1200,7 @@ void nwos_initialize_objectify(AccessType type, const char* path)
     nwos_log("nwos_initialize_objectify():");
 
     nwos_crc32_initialize();
-    nwos_initialize_disk_io(type, path);
+    nwos_initialize_storage(type, path);
 
     if (type == PUBLIC)
     {
@@ -1209,7 +1234,7 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 
 	if (attempt == NUM_ATTEMPTS)
 	{
-	    nwos_terminate_disk_io();
+	    nwos_terminate_storage();
 	    fprintf(stderr, "\n");
 	    exit(1);
 	}
@@ -1218,8 +1243,6 @@ void nwos_initialize_objectify(AccessType type, const char* path)
 }
 
 
-static bool creating_root = false;
-
 /* this is the same as the normal routine in objectify.c except it doesn't translate the reference for the disk */
 static void set_public_root_object(ObjRef* ref)
 {
@@ -1254,7 +1277,7 @@ void nwos_create_root(void)
     nwos_log("nwos_create_root():");
 
     nwos_crc32_initialize();
-    nwos_initialize_disk_io(READ_WRITE, DEFAULT_FILE);
+    nwos_initialize_storage(READ_WRITE, DEFAULT_FILE);
 
     assert(nwos_archive_is_file() || nwos_total_private_chunks > nwos_used_private_chunks);
 
@@ -1345,9 +1368,7 @@ void nwos_create_root(void)
 
     nwos_crc32_calculate((uint8*) &root_obj.class_definition_class, sizeof(root_obj) - sizeof(EveryObject), root_obj.header.common.data_chksum);
 
-    creating_root = true;
     nwos_write_object_to_disk(&private_root_obj_ref, &root_obj, sizeof(root_obj));
-    creating_root = false;
 
     nwos_terminate_objectify();
 }
@@ -1366,13 +1387,13 @@ bool nwos_set_root_object(ObjRef* ref)
     {
 	if (nwos_reference_type(ref) == Public_Reference)
 	{
-	    assert(nwos_private_path == NULL);   /* only allow if no private objects are in play */
+	    assert(nwos_storage_is_public_only());   /* only allow if no private objects are in play */
 
 	    copy_reference(&nwos_public_class_definition_class_ref, &root_obj.class_definition_class);
 	}
 	else
 	{
-	    assert(nwos_private_path != NULL);   /* only allow if private objects are in play */
+	    assert(!nwos_storage_is_public_only());   /* only allow if private objects are in play */
 
 	    copy_reference(&nwos_private_class_definition_class_ref, &root_obj.class_definition_class);
 
@@ -1393,6 +1414,13 @@ bool nwos_set_root_object(ObjRef* ref)
 }
 
 
+void nwos_flush_to_disk()
+{
+    nwos_flush_dirty_ref_lists();  /* flush any reference lists that are dirty out to disk */
+    nwos_flush_storage();
+}
+
+
 void nwos_terminate_objectify()
 {
     nwos_log("nwos_terminate_objectify():");
@@ -1401,7 +1429,7 @@ void nwos_terminate_objectify()
 
     nwos_flush_dirty_ref_lists();  /* flush any reference lists that are dirty out to disk */
 
-    nwos_terminate_disk_io();
+    nwos_terminate_storage();
 
 #ifdef CHECK_MEMORY_LEAKS
     for (i = 0; i < MAX_MEM_ADDR_SAVED; i++)
@@ -1418,584 +1446,10 @@ bool nwos_in_public_mode()
 }
 
 
-/*************************/
-/* Verification routines */
-/*************************/
-
-#if 0
-static void check_common_header(ObjRef* ref, CommonHeader* common)
+const char* nwos_archive_version()
 {
-  /* could check time stamp is valid here?  anything else? */
+    return nwos_version_string;
 }
-#endif
-
-
-static bool object_header_checksum_matches(ObjectHeader* obj_header, uint8 stored[4])
-{
-    uint8 computed[4];
-
-    nwos_crc32_calculate((uint8*)obj_header, sizeof(*obj_header), computed);
-
-    return (stored[0] == computed[0] && stored[1] == computed[1] && stored[2] == computed[2] && stored[3] == computed[3]);
-}
-
-
-static bool check_object_data(ObjRef* ref, uint8* object, size_t total_size, uint8 stored[4])
-{
-    uint8 computed[4];
-    size_t data_size;
-
-    data_size = total_size - sizeof(EveryObject);
-
-#if 0
-    printf("Total size: %d\n", total_size);
-    printf("ObjectHeader: %d\n", sizeof(EveryObject));
-    printf("object pointer: %p\n", object);
-    {
-      int i;
-      uint8* ptr = (uint8*)object + sizeof(EveryObject);
-      printf("data pointer: %p\n", ptr);
-      printf("data: ");
-      for (i = 0; i < data_size; i++) printf("%02x%c", *ptr++, i%16==15?'\n':' ');
-      printf("\n");
-    }
-#endif
-
-    nwos_crc32_calculate((uint8*)object + sizeof(EveryObject), data_size, computed);
-
-    return memcmp(computed, stored, sizeof(computed)) == 0;
-}
-
-
-/*********************************/
-/* Routines to read objects, etc */
-/*********************************/
-
-#define SIZE_EXTRA_BLOCK_DATA (FILE_BLOCK_SIZE - sizeof(uint32) - sizeof(ObjRef) - sizeof(ObjRef))
-
-typedef struct
-{
-    uint8  flags[4];
-    ObjRef id;
-    uint8  data[SIZE_EXTRA_BLOCK_DATA];
-    ObjRef next_block;
-} Extra_Data_Block;
-
-
-bool nwos_read_object_from_disk(ObjRef* ref, void* object, size_t size)
-{
-    EveryObject* header;
-    uint8 ivec[IVEC_SIZE];
-    uint8* ptr_obj;
-    Extra_Data_Block extra;
-    ObjRef next_ref;
-    size_t bytes_remaining;
-    int i;
-    int seq = 0;
-    bool use_old_decryption = false;
-
-    assert(!is_void_reference(ref));
-
-#if 0
-    char log_msg[128];
-
-    snprintf(log_msg, sizeof(log_msg), "nwos_read_object_from_disk - %s size: %d", path, size);
-    nwos_log(log_msg);
-#endif
-
-    assert(size > sizeof(CommonHeader));  /* make sure this wasn't called to just get the header */
-
-    memset(ivec, 0, sizeof(ivec));
-
-    bytes_remaining = size;
-
-    ptr_obj = object;
-
-    if (!nwos_read_block_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, seq)) return false;
-
-    assert(sizeof(ObjRef) == 4);
-
-    header = (EveryObject*) &extra;
-
-    /* check_common_header(ref, &header->common);     -- this doesn't do anything right now */
-
-    if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* could be old encryption */
-    {
-#ifdef PUBLIC_MODE
-	return false;
-#else
-	memset(ivec, 0, sizeof(ivec));
-	if (!nwos_read_block_from_disk_and_old_decrypt(ref, &extra, sizeof(extra), ivec, seq)) return false;
-
-	if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* neither decryption worked */
-	{
-	    return false;
-	}
-
-	use_old_decryption = true;
-#endif
-    }
-
-    *ptr_obj++ = extra.flags[0];
-    *ptr_obj++ = extra.flags[1];
-    *ptr_obj++ = extra.flags[2];
-    *ptr_obj++ = extra.flags[3];
-    *ptr_obj++ = extra.id.id[0];
-    *ptr_obj++ = extra.id.id[1];
-    *ptr_obj++ = extra.id.id[2];
-    *ptr_obj++ = extra.id.id[3];
-
-
-    while (bytes_remaining > FILE_BLOCK_SIZE)
-    {
-	for (i = 0; i < SIZE_EXTRA_BLOCK_DATA; i++)
-	{
-	    *ptr_obj++ = extra.data[i];
-	    bytes_remaining--;
-	}
-
-	/* save the reference because the extra block is going to get written over, we don't want it to change */
-	copy_reference(&next_ref, &extra.next_block);
-
-	seq++;
-
-	if (use_old_decryption)
-	{
-	    if (!nwos_read_block_from_disk_and_old_decrypt(&next_ref, &extra, sizeof(extra), ivec, seq)) return false;
-	}
-	else
-	{
-	    if (!nwos_read_block_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, seq)) return false;
-	}
-
-    }
-
-    assert(bytes_remaining <= FILE_BLOCK_SIZE);
-
-    for (i = 0; i < bytes_remaining - 8; i++) *ptr_obj++ = extra.data[i];
-
-#if 0
-    printf("read obj path: %s\n", path);
-    printf("read obj pointer: %p\n", object);
-    {
-      int i;
-      for (i = 0; i < size; i++) printf("%02x%c", *((uint8*)object+i), i%16==15?'\n':' ');
-      printf("\n");
-    }
-#endif
-
-    header = (EveryObject*) object;
-
-#ifndef USE_PREDEFINED_STRUCTS
-#ifndef PUBLIC_MODE
-    /* check to see if this is a file object (which has an older revision) */
-    if (nwos_reference_type(ref) == Private_Reference && is_same_object(&header->common.class_definition, nwos_get_file_001_reference()))
-    {
-	if (check_object_data(ref, (uint8*)object, sizeof(C_struct_File_001), header->common.data_chksum))
-	{
-	    nwos_update_file_001_object_to_current(object, size);
-	    return true;
-	}
-    }
-    else if (nwos_reference_type(ref) == Private_Reference && is_same_object(&header->common.class_definition, nwos_get_file_002_reference()))
-    {
-	if (check_object_data(ref, (uint8*)object, sizeof(C_struct_File_002), header->common.data_chksum))
-	{
-	    nwos_update_file_002_object_to_current(object, size);
-	    return true;
-	}
-    }
-    else
-#endif
-#endif
-    {
-	if (check_object_data(ref, (uint8*)object, size, header->common.data_chksum))
-	{
-	    return true;
-	}
-    }
-
-    return false;
-}
-
-
-bool nwos_read_variable_sized_object_from_disk(ObjRef* ref, void* object, size_t max_size, size_t (*size_function)(void*))
-{
-    EveryObject* header;
-    uint8 ivec[IVEC_SIZE];
-    uint8* ptr_obj;
-    Extra_Data_Block extra;
-    ObjRef next_ref;
-    size_t bytes_remaining;
-    int i;
-    int seq = 0;
-    size_t xyzzy;
-    char msg[128];
-    bool use_old_decryption = false;
-
-    assert(!is_void_reference(ref));
-
-#if 0
-    char log_msg[128];
-
-    snprintf(log_msg, sizeof(log_msg), "nwos_read_variable_size_object_from_disk - %s size: %d", path, size);
-    nwos_log(log_msg);
-#endif
-
-    memset(ivec, 0, sizeof(ivec));
-
-    ptr_obj = object;
-
-    if (!nwos_read_block_from_disk_and_decrypt(ref, &extra, sizeof(extra), ivec, seq)) return false;
-
-    assert(sizeof(ObjRef) == 4);
-
-    header = (EveryObject*) &extra;
-
-    /* check_common_header(ref, &header->common);     -- this doesn't do anything right now */
-
-    if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* could be old encryption */
-    {
-#ifdef PUBLIC_MODE
-	return false;
-#else
-	memset(ivec, 0, sizeof(ivec));
-	if (!nwos_read_block_from_disk_and_old_decrypt(ref, &extra, sizeof(extra), ivec, seq)) return false;
-
-	if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* neither decryption worked */
-	{
-	    return false;
-	}
-
-	use_old_decryption = true;
-#endif
-    }
-
-    *ptr_obj++ = extra.flags[0];
-    *ptr_obj++ = extra.flags[1];
-    *ptr_obj++ = extra.flags[2];
-    *ptr_obj++ = extra.flags[3];
-    *ptr_obj++ = extra.id.id[0];
-    *ptr_obj++ = extra.id.id[1];
-    *ptr_obj++ = extra.id.id[2];
-    *ptr_obj++ = extra.id.id[3];
-
-    bytes_remaining = (*size_function)(&extra);
-    xyzzy = nwos_get_object_size(&extra);
-
-    //    assert(xyzzy == 0 || bytes_remaining == xyzzy);
-    if (xyzzy != 0 && bytes_remaining != xyzzy)
-    {
-	snprintf(msg, sizeof(msg), "Warning: size_function: %zd  get_object_size: %zd", bytes_remaining, xyzzy);
-	nwos_log(msg);
-	printf("%s\n", msg);
-    }
-
-    assert(bytes_remaining <= max_size);
-
-    while (bytes_remaining > FILE_BLOCK_SIZE)
-    {
-	for (i = 0; i < SIZE_EXTRA_BLOCK_DATA; i++)
-	{
-	    *ptr_obj++ = extra.data[i];
-	    bytes_remaining--;
-	}
-
-	/* save the reference because the extra block is going to get written over, we don't want it to change */
-	copy_reference(&next_ref, &extra.next_block);
-
-	seq++;
-
-
-	if (use_old_decryption)
-	{
-	    if (!nwos_read_block_from_disk_and_old_decrypt(&next_ref, &extra, sizeof(extra), ivec, seq)) return false;
-	}
-	else
-	{
-	    if (!nwos_read_block_from_disk_and_decrypt(&next_ref, &extra, sizeof(extra), ivec, seq)) return false;
-	}
-    }
-
-    assert(bytes_remaining <= FILE_BLOCK_SIZE);
-
-    for (i = 0; i < bytes_remaining - 8; i++) *ptr_obj++ = extra.data[i];
-
-#if 0
-    printf("read obj path: %s\n", path);
-    printf("read obj pointer: %p\n", object);
-    {
-      int i;
-      for (i = 0; i < size; i++) printf("%02x%c", *((uint8*)object+i), i%16==15?'\n':' ');
-      printf("\n");
-    }
-#endif
-
-    header = (EveryObject*) object;
-
-    return check_object_data(ref, (uint8*)object, (*size_function)(object), header->common.data_chksum);
-}
-
-
-void nwos_read_object_headers_from_disk(ObjRef* ref, EveryObject* header)
-{
-    uint8 ivec[IVEC_SIZE];
-
-    assert(!is_void_reference(ref));
-
-    memset(ivec, 0, sizeof(ivec));
-    assert(nwos_read_block_from_disk_and_decrypt(ref, header, sizeof(*header), ivec, 0));
-
-    /* check_common_header(ref, &header->common); -- this currently doesn't do anything */
-
-    if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* could be old encryption */
-    {
-#ifdef PUBLIC_MODE
-	printf("\n");
-	fflush(stdout);
-	fprintf(stderr, "Unable to decrypt object headers: %08x\n", nwos_ref_to_word(ref));
-	nwos_terminate_objectify();
-	exit(1);
-#else
-	memset(ivec, 0, sizeof(ivec));
-	assert(nwos_read_block_from_disk_and_old_decrypt(ref, header, sizeof(*header), ivec, 0));
-
-	if (!object_header_checksum_matches(&header->object, header->common.header_chksum))   /* neither decryption worked */
-	{
-	    printf("\n");
-	    fflush(stdout);
-	    fprintf(stderr, "Unable to decrypt object headers: %08x\n", nwos_ref_to_word(ref));
-	    nwos_terminate_objectify();
-	    exit(1);
-	}
-#endif
-    }
-
-#if 0
-    printf("read header path: %s\n", path);
-    printf("read header pointer: %p\n", header);
-    {
-      int i;
-      for (i = 0; i < sizeof(EveryObject); i++) printf("%02x%c", *((uint8*)header+i), i%16==15?'\n':' ');
-      printf("\n");
-    }
-#endif
-}
-
-
-/**********************************/
-/* Routines to write objects, etc */
-/**********************************/
-
-void nwos_write_object_to_disk(ObjRef* ref, void* object, size_t size)
-{
-    uint8 ivec[IVEC_SIZE];
-    uint8* ptr_obj;
-    Extra_Data_Block extra;
-    size_t bytes_remaining;
-    int i;
-    int seq = 0;
-
-    memset(ivec, 0, sizeof(ivec));
-
-
-    assert(sizeof(extra) == FILE_BLOCK_SIZE);
-
-#ifdef PUBLIC_MODE
-    assert(nwos_reference_type(&((EveryObject*)object)->common.class_definition) == Public_Reference);
-#else
-    assert(nwos_reference_type(&((EveryObject*)object)->common.class_definition) == Private_Reference || creating_root);
-    assert(nwos_block_used(ref));      /* assert bit in map was set by generate id */
-#endif
-
-#ifdef VERIFY_BLOCK_IS_EMPTY
-    /* NOTE: this was before using the bit map to verify that the block wasn't already */
-    /* used, now we assume the bit map is correct even if the block is non-zero */
-    assert(!nwos_read_block(ref, block) || is_void_reference((ObjRef*)&block[4]));   /* make sure block is zero */
-#endif
-
-    ptr_obj = (uint8*) object;
-
-    assert(ptr_obj[0] == 0 && ptr_obj[1] == 0 && ptr_obj[2] == 0 && ptr_obj[3] == 0);
-
-    ptr_obj += 4;
-
-    assert(is_same_object(ref, (ObjRef*)ptr_obj));
-
-    ptr_obj += 4;
-
-    bytes_remaining = size;
-
-    extra.flags[0] = 0;
-    extra.flags[1] = 0;
-    extra.flags[2] = 0;
-    extra.flags[3] = 0;
-
-    copy_reference(&extra.id, ref);
-
-    while (bytes_remaining > FILE_BLOCK_SIZE)
-    {
-	for (i = 0; i < SIZE_EXTRA_BLOCK_DATA; i++)
-	{
-	    extra.data[i] = *ptr_obj++;
-	    bytes_remaining--;
-	}
-
-	nwos_generate_new_id(&extra.next_block);
-
-	nwos_write_block_to_disk_and_encrypt(&extra.id, &extra, sizeof(extra), ivec, seq);
-
-	copy_reference(&extra.id, &extra.next_block);
-
-	seq++;
-    }
-
-    assert(bytes_remaining <= FILE_BLOCK_SIZE);
-
-    for (i = 0; i < bytes_remaining - 8; i++) extra.data[i] = *ptr_obj++;
-
-    nwos_write_block_to_disk_and_encrypt(&extra.id, &extra, bytes_remaining, ivec, seq);
-}
-
-
-void nwos_overwrite_object_to_disk(ObjRef* ref, void* object, size_t size)
-{
-    uint8 ivec[IVEC_SIZE];
-    uint8 block[FILE_BLOCK_SIZE];
-
-    assert(size <= FILE_BLOCK_SIZE);        /* this function cannot handle objects larger than one block yet!! */
-    assert(nwos_read_block(ref, block));    /* verify that there is already an object there */
-
-#ifdef PUBLIC_MODE
-    assert(nwos_reference_type(&((EveryObject*)object)->common.class_definition) == Public_Reference);
-#else
-    assert(nwos_reference_type(&((EveryObject*)object)->common.class_definition) == Private_Reference);
-    assert(nwos_block_used(ref));      /* assert bit in map was set by generate id */
-#endif
-
-    memset(ivec, 0, sizeof(ivec));
-
-    nwos_write_block_to_disk_and_encrypt(ref, object, size, ivec, 0);
-}
-
-
-#ifndef PUBLIC_MODE
-void nwos_remove_object(ObjRef* ref)
-{
-    /* this function should read the object and erase all blocks, functions should not call this to erase a block, they should call erase_block */
-
-    bool this_needs_to_be_fixed_to_handle_multiple_block_objects = false;
-
-    assert(this_needs_to_be_fixed_to_handle_multiple_block_objects);
-
-    nwos_erase_block(ref);
-}
-#endif
-
-
-void nwos_write_public_object_to_disk(ObjRef* ref, void* object, size_t size)
-{
-    uint8 block[FILE_BLOCK_SIZE];
-//    int i;
-
-    assert(size <= FILE_BLOCK_SIZE);
-    assert((ref->id[0] & 0xF0) == 0);
-
-    memset(block, 0, sizeof(block));
-
-    memcpy(block, object, size);
-
-    nwos_write_block(ref, block);
-
-//    printf("write_public_object: %02x%02x%02x%02x", ref->id[0], ref->id[1], ref->id[2], ref->id[3]);
-}
-
-
-/***************/
-/* Class stuff */
-/***************/
-
-/*--------------------------------------------------------------------------------*/
-/* Get an object's class reference, without updating to the latest class revision */
-/*--------------------------------------------------------------------------------*/
-
-void nwos_get_object_class_without_update(ObjRef* obj, ObjRef* object_class)
-{
-    EveryObject header;
-    uint8 ivec[IVEC_SIZE];
-
-    assert(!is_void_reference(obj));
-
-    memset(ivec, 0, sizeof(ivec));
-
-    assert(nwos_read_block_from_disk_and_decrypt(obj, &header, sizeof(header), ivec, 0));
-
-    /* check_common_header(obj, &header.common);  -- this doesn't currently do anything */
-
-    /* if it is not a reference list check the header checksum */
-
-    if (!is_same_object(&header.common.class_definition, &nwos_reference_list_class_ref))
-    {
-	if (!object_header_checksum_matches(&header.object, header.common.header_chksum))   /* could be old encryption */
-	{
-#ifdef PUBLIC_MODE
-	    printf("\n");
-	    fflush(stdout);
-	    fprintf(stderr, "Unable to decrypt object class without update: %08x\n", nwos_ref_to_word(obj));
-	    nwos_terminate_objectify();
-	    exit(1);
-#else
-	    memset(ivec, 0, sizeof(ivec));
-	    assert(nwos_read_block_from_disk_and_old_decrypt(obj, &header, sizeof(header), ivec, 0));
-
-	    if (!is_same_object(&header.common.class_definition, &nwos_reference_list_class_ref))
-	    {
-		if (!object_header_checksum_matches(&header.object, header.common.header_chksum))   /* neither decryption worked */
-		{
-		    printf("\n");
-		    fflush(stdout);
-		    fprintf(stderr, "Unable to decrypt object class without update: %08x\n", nwos_ref_to_word(obj));
-		    nwos_terminate_objectify();
-		    exit(1);
-		}
-	    }
-#endif
-	}
-    }
-
-    copy_reference(object_class, &header.common.class_definition);
-}
-
-
-/*-------------------------------------------------------------------------*/
-/* Get an object's class reference and update to the latest class revision */
-/*-------------------------------------------------------------------------*/
-
-void nwos_get_object_class(ObjRef* obj, ObjRef* object_class)
-{
-    nwos_get_object_class_without_update(obj, object_class);
-
-#ifndef USE_PREDEFINED_STRUCTS
-    if (nwos_reference_type(obj) == Private_Reference && is_same_object(object_class, nwos_get_file_001_reference()))
-    {
-	copy_reference(object_class, nwos_get_file_class_reference());
-    }
-    else if (nwos_reference_type(obj) == Private_Reference && is_same_object(object_class, nwos_get_file_002_reference()))
-    {
-	copy_reference(object_class, nwos_get_file_class_reference());
-    }
-#endif
-}
-
-
-void nwos_fill_in_common_header(CommonHeader* common, ObjRef* ref, ObjRef* class_definition_ref)
-{
-    memset(common, 0, sizeof(CommonHeader));
-    memcpy(&common->id, ref, sizeof(ObjRef));
-    nwos_get_time_stamp(common->creation_time);
-    memcpy(&common->class_definition, class_definition_ref, sizeof(common->class_definition));
-}
-
 
 
 bool nwos_is_quit_command(char* command)
