@@ -27,12 +27,51 @@
 --
 --
 -- $Log: patch_compressed.c,v $
+-- Revision 1.19  2009/07/18 16:07:40  jsedwards
+-- Added code to set the upper 4 bytes of the reference in blocks from a 0029
+-- or older file to 0xfffffffe and back to zero if the block has to go around
+-- again.
+--
+-- Revision 1.18  2009/07/18 02:33:14  jsedwards
+-- Fixed to deal with having 0xfffffffe in the upper word of the reference in
+-- each block if the version > 29.
+--
+-- Revision 1.17  2009/07/17 14:36:52  jsedwards
+-- Fixed to print message to stderr when upper four bytes of block reference
+-- are not zero and to exit with error code.  Added test for patch file block
+-- and when finishing compressed file or patch file.
+--
+-- Revision 1.16  2009/07/11 13:31:28  jsedwards
+-- Changed to pass TYPE_CODE_COMPRESSED and TYPE_CODE_DIFF in the calls to
+-- check disk header.
+--
+-- Revision 1.15  2009/07/10 15:06:35  jsedwards
+-- Changed to write compressed into the disk header of the output file if it
+-- is version 0030 or above.
+--
+-- Revision 1.14  2009/07/05 13:07:31  jsedwards
+-- Removed code that converted the 0022_to_0029 header to a 0030 header because
+-- it was wrong and I am not sure it was necessary anyway.
+--
+-- Revision 1.13  2009/07/03 13:49:08  jsedwards
+-- Changed to include new header.h file instead of disk_io.h and to use new
+-- nwos_check_disk_header function to verify header is correct.
+--
+-- Revision 1.12  2009/04/06 14:28:13  jsedwards
+-- Merged in changes from CVS branch_0030_new_chunk_info branch, see revision
+-- 1.9.2.1 below.
+--
 -- Revision 1.11  2009/03/08 00:39:05  jsedwards
 -- Changed include objectify_private.h to disk_io.h.
 --
 -- Revision 1.10  2008/09/01 00:10:52  jsedwards
 -- Fix copyright year.  NO code changes.
 --
+-- Revision 1.9.2.1  2008/08/16 12:41:50  jsedwards
+-- Added new convert_0022_to_0029_header_to_0030_header function to convert an
+-- old header to the new 0030 header.  Also changed total_blocks to total_chunks
+-- for new Disk_Header.
+--
 -- Revision 1.9  2008/02/02 11:24:41  jsedwards
 -- Added code to print the number of used blocks in the old file and the patch
 -- when they don't match.
@@ -73,7 +112,7 @@
 #include <string.h>
 #include <unistd.h>    /* define sleep() */
 
-#include "disk_io.h"
+#include "header.h"
 
 
 uint32 convert_4_uint8_to_uint32(uint8 byte[4])
@@ -101,6 +140,26 @@ static int version_string_to_int(char string[4])
     return result;
 }
 
+#if 0
+static void convert_0022_to_0029_header_to_0030_header(Disk_Header_0022_to_0029* header_0029, Disk_Header* header_0030)
+{
+    uint32 total_blocks;
+    uint32 total_chunks;
+
+    /* NOTE: this won't work because the sizes of the variables are different (32 bits vs. 64 bits) */
+    /* But I am not sure this is even necessary because the diff file should have the correct headers */
+
+    memcpy(header_0030->last_prep_disk,         header_0029->last_prep_disk,         sizeof(header_0030->last_prep_disk));
+    memcpy(header_0030->last_change,            header_0029->last_change,            sizeof(header_0030->last_change));
+    memcpy(header_0030->block_offset_to_chunks, header_0029->block_offset_to_chunks, sizeof(header_0030->block_offset_to_chunks));
+    memcpy(header_0030->used_blocks,            header_0029->used_blocks,            sizeof(header_0030->used_blocks));
+    memcpy(header_0030->used_chunks,            header_0029->used_chunks,            sizeof(header_0030->used_chunks));
+
+    nwos_4_uint8_to_uint32(header_0029->total_blocks, &total_blocks);
+    total_chunks = total_blocks / 65536;
+    nwos_uint32_to_4_uint8(&total_chunks, header_0030->total_chunks);
+}
+#endif
 
 int main(int argc, char* argv[])
 {
@@ -117,6 +176,7 @@ int main(int argc, char* argv[])
     Disk_Header header1;
     Disk_Header header2;
     bool wrapped_file = false;     /* true if older file that wasn't sequencial */
+    bool bad_upper_ref;
     int header1_version;
     int header2_version;
     int in1;
@@ -124,6 +184,7 @@ int main(int argc, char* argv[])
     int out3;
     bool ignore_times;
     bool mismatch = false;
+    const char* error_msg;
 
 
     if (argc == 4)
@@ -174,9 +235,11 @@ int main(int argc, char* argv[])
 
     memcpy(&header1, buf1, sizeof(header1));
 
-    if (memcmp(header1.magic_number, "NWOS", 4) != 0)
+    error_msg = nwos_check_disk_header(&header1, true, TYPE_CODE_COMPRESSED);   /* allow older versions */
+
+    if (error_msg != NULL)
     {
-	fprintf(stderr, "Not an Objectify file: %s\n", argv[in1]);
+	fprintf(stderr, "%s: %s\n", error_msg, argv[in1]);
 	fclose(fp1);
 	exit(1);
     }
@@ -221,9 +284,11 @@ int main(int argc, char* argv[])
 
     memcpy(&header2, buf2, sizeof(header2));
 
-    if (memcmp(header2.magic_number, "NWOS", 4) != 0)
+    error_msg = nwos_check_disk_header(&header2, true, TYPE_CODE_DIFF);   /* allow older versions */
+
+    if (error_msg != NULL)
     {
-	fprintf(stderr, "Not an Objectify patch file: %s\n", argv[in2]);
+	fprintf(stderr, "%s: %s\n", error_msg, argv[in2]);
 	fclose(fp1);
 	fclose(fp2);
 	exit(1);
@@ -260,9 +325,9 @@ int main(int argc, char* argv[])
 	}
     }
 
-    if (memcmp(header1.total_blocks, header2.total_blocks, sizeof(header1.total_blocks)) != 0)
+    if (memcmp(header1.total_chunks, header2.total_chunks, sizeof(header1.total_chunks)) != 0)
     {
-	fprintf(stderr, "Old file total blocks doesn't match patch file total blocks!\n");
+	fprintf(stderr, "Old file total chunks doesn't match patch file total chunks!\n");
 	mismatch = true;
     }
 
@@ -358,6 +423,11 @@ int main(int argc, char* argv[])
 	exit(1);
     }
 
+    if (header2_version >= 30)
+    {
+	memcpy(&(((Disk_Header*)buf2)->type_code), TYPE_CODE_COMPRESSED, sizeof((((Disk_Header*)buf2)->type_code)));
+    }
+
     write3 = fwrite(buf2, 1, sizeof(buf2), fp3);
 
     if (write3 != FILE_BLOCK_SIZE)
@@ -377,11 +447,61 @@ int main(int argc, char* argv[])
 
     while (!feof(fp1) && !feof(fp2) && read1 == FILE_BLOCK_SIZE && read2 == FILE_BLOCK_SIZE)
     {
-	if (buf1[0] != 0 || buf1[1] != 0 || buf1[2] != 0 || buf1[3] != 0)
+	bad_upper_ref = false;
+
+	if (header1_version < 30)
 	{
-	    printf("\n%s block %d - first four bytes not zero: %02x%02x%02x%02x\n",
-		   argv[in1], block1, buf1[0], buf1[1], buf1[2], buf1[3]);
-	    break;
+	    if (buf1[0] != 0 || buf1[1] != 0 || buf1[2] != 0 || buf1[3] != 0)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not zero: %02x%02x%02x%02x\n",
+			argv[in1], block1, buf1[0], buf1[1], buf1[2], buf1[3]);
+		bad_upper_ref = true;
+	    }
+
+	    if (header2_version >= 30)
+	    {
+		buf1[0] = 0xff;
+		buf1[1] = 0xff;
+		buf1[2] = 0xff;
+		buf1[3] = 0xfe;
+	    }
+	}
+	else 
+	{
+	    if (buf1[0] != 0xff || buf1[1] != 0xff || buf1[2] != 0xff || buf1[3] != 0xfe)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not fffffffe: %02x%02x%02x%02x\n",
+			argv[in1], block1, buf1[0], buf1[1], buf1[2], buf1[3]);
+		bad_upper_ref = true;
+	    }
+	}
+
+	if (header2_version < 30)
+	{
+	    if (buf2[0] != 0 || buf2[1] != 0 || buf2[2] != 0 || buf2[3] != 0)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not zero: %02x%02x%02x%02x\n",
+			argv[in2], block2, buf2[0], buf2[1], buf2[2], buf2[3]);
+		bad_upper_ref = true;
+	    }
+	}
+	else
+	{
+	    if (buf2[0] != 0xff || buf2[1] != 0xff || buf2[2] != 0xff || buf2[3] != 0xfe)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not fffffffe: %02x%02x%02x%02x\n",
+			argv[in2], block2, buf2[0], buf2[1], buf2[2], buf2[3]);
+		bad_upper_ref = true;
+	    }
+	}
+
+	if (bad_upper_ref)
+	{
+	    fclose(fp1);
+	    fclose(fp2);
+	    fclose(fp3);
+
+	    exit(1);
 	}
 
 	if (buf1[4] == buf2[4] && buf1[5] == buf2[5] && buf1[6] == buf2[6] && buf1[7] == buf2[7])
@@ -458,6 +578,15 @@ int main(int argc, char* argv[])
 
 		    read2 = fread(buf2, 1, sizeof(buf2), fp2);
 		    block2++;
+
+		    /* Change the upper 4 bytes back because we are going through the loop again */
+		    if (header1_version < 30 && header2_version >= 30)
+		    {
+			buf1[0] = 0;
+			buf1[1] = 0;
+			buf1[2] = 0;
+			buf1[3] = 0;
+		    }
 		}
 		else  /* not time to insert yet, just write the old block */
 		{
@@ -484,6 +613,44 @@ int main(int argc, char* argv[])
 
     while (!feof(fp1) && read1 == FILE_BLOCK_SIZE)
     {
+	bad_upper_ref = false;
+
+	if (header1_version < 30)
+	{
+	    if (buf1[0] != 0 || buf1[1] != 0 || buf1[2] != 0 || buf1[3] != 0)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not zero: %02x%02x%02x%02x\n",
+			argv[in1], block1, buf1[0], buf1[1], buf1[2], buf1[3]);
+		bad_upper_ref = true;
+	    }
+
+	    if (header2_version >= 30)
+	    {
+		buf1[0] = 0xff;
+		buf1[1] = 0xff;
+		buf1[2] = 0xff;
+		buf1[3] = 0xfe;
+	    }
+	}
+	else 
+	{
+	    if (buf1[0] != 0xff || buf1[1] != 0xff || buf1[2] != 0xff || buf1[3] != 0xfe)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not fffffffe: %02x%02x%02x%02x\n",
+			argv[in1], block1, buf1[0], buf1[1], buf1[2], buf1[3]);
+		bad_upper_ref = true;
+	    }
+	}
+
+	if (bad_upper_ref)
+	{
+	    fclose(fp1);
+	    fclose(fp2);
+	    fclose(fp3);
+
+	    exit(1);
+	}
+
 	write3 = fwrite(buf1, 1, sizeof(buf1), fp3);
 
 	if (write3 != FILE_BLOCK_SIZE)
@@ -503,6 +670,36 @@ int main(int argc, char* argv[])
 
     while (!feof(fp2) && read2 == FILE_BLOCK_SIZE)
     {
+	bad_upper_ref = false;
+
+	if (header2_version < 30)
+	{
+	    if (buf2[0] != 0 || buf2[1] != 0 || buf2[2] != 0 || buf2[3] != 0)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not zero: %02x%02x%02x%02x\n",
+			argv[in2], block2, buf2[0], buf2[1], buf2[2], buf2[3]);
+		bad_upper_ref = true;
+	    }
+	}
+	else
+	{
+	    if (buf2[0] != 0xff || buf2[1] != 0xff || buf2[2] != 0xff || buf2[3] != 0xfe)
+	    {
+		fprintf(stderr, "\n%s block %d - first four bytes not fffffffe: %02x%02x%02x%02x\n",
+			argv[in2], block2, buf2[0], buf2[1], buf2[2], buf2[3]);
+		bad_upper_ref = true;
+	    }
+	}
+
+	if (bad_upper_ref)
+	{
+	    fclose(fp1);
+	    fclose(fp2);
+	    fclose(fp3);
+
+	    exit(1);
+	}
+
 	printf("%02x%02x%02x%02x: added\n", buf2[4], buf2[5], buf2[6], buf2[7]);
 
 	write3 = fwrite(buf2, 1, sizeof(buf2), fp3);
@@ -517,7 +714,7 @@ int main(int argc, char* argv[])
 	}
 
 	read2 = fread(buf2, 1, sizeof(buf2), fp2);
-	block1++;
+	block2++;
     }
 
     printf("\n");
