@@ -27,9 +27,15 @@
 --
 --
 -- $Log: reference_list.c,v $
+-- Revision 1.47  2009/06/13 12:53:14  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.45.2.1  2009/05/23 03:48:03  jsedwards
 -- Moved endif so that nwos_flush_dirty_ref_lists get compiled in public mode.
 --
+-- Revision 1.46  2009/04/19 14:20:05  jsedwards
+-- Added include of chunk_info.h file to define nwos_hash_ref.
+--
 -- Revision 1.45  2009/03/14 20:25:52  jsedwards
 -- Fix bug introduced in previous check-in where seq was not set to block_num.
 --
@@ -214,6 +220,7 @@
 #include <string.h>
 
 #include "bit_map.h"
+#include "chunk_info.h"                /* define nwos_hash_ref */
 #include "class_definition.h"
 #include "crc32.h"
 #include "disk_io.h"
