@@ -27,6 +27,11 @@
 --
 --
 -- $Log: rename_file.c,v $
+-- Revision 1.22  2009/07/19 13:21:44  jsedwards
+-- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
+-- were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
 -- Revision 1.21  2009/03/19 11:38:21  jsedwards
 -- Wrapped call to nwos_set_security_level with ifdef CHANGE_SECURITY_TO_DENSITY
 -- because what was called security level stuff is temporarily disabled.
@@ -170,7 +175,9 @@ static char* file_is_used_in_disc_list(ObjRef* disc_list_class_ref, C_struct_Pat
 
 void create_new_path(char* new_path, C_struct_Path_And_File_Association *assoc_obj)
 {
+#ifdef VERIFY_WRITE
     C_struct_Path_And_File_Association temp;
+#endif
     ObjRef assoc_class_ref;
     ObjRef new_path_ref;
     ObjRef old_assoc_ref;
@@ -198,9 +205,11 @@ void create_new_path(char* new_path, C_struct_Path_And_File_Association *assoc_o
 
     nwos_overwrite_object_to_disk(&old_assoc_ref, assoc_obj, sizeof(*assoc_obj));
 
+#ifdef VERIFY_WRITE
     /* read back to verify */
     assert(nwos_read_object_from_disk(&old_assoc_ref, &temp, sizeof(temp)));
     assert(memcmp(&temp, assoc_obj, sizeof(temp)) == 0);
+#endif
 
     void_reference(&assoc_obj->header.object.next_version);   /* remove it before creating the new */
 
@@ -227,9 +236,11 @@ void create_new_path(char* new_path, C_struct_Path_And_File_Association *assoc_o
     nwos_add_to_references(&new_assoc_ref, &assoc_obj->path);
     nwos_add_to_references(&new_assoc_ref, &assoc_obj->file);
 
+#ifdef VERIFY_WRITE
     /* read back to verify */
     assert(nwos_read_object_from_disk(&new_assoc_ref, &temp, sizeof(temp)));
     assert(memcmp(&temp, assoc_obj, sizeof(temp)) == 0);
+#endif
 }
 
 
