@@ -27,6 +27,14 @@
 --
 --
 -- $Log: security.c,v $
+-- Revision 1.27  2009/04/13 13:25:24  jsedwards
+-- Change include of gen_id.h file to new storage.h file which now contains
+-- the nwos_read_block and nwos_write_block functions.
+--
+-- Revision 1.26  2009/04/12 00:41:17  jsedwards
+-- Added include for gen_id.h file which now contains the nwos_read_block and
+-- nwos_write_block function declarations.
+--
 -- Revision 1.25  2009/03/14 19:08:10  jsedwards
 -- Moved security related variables and functions from objectify.c file.
 --
@@ -144,8 +152,9 @@
 #include <unistd.h>
 
 #include "crc32.h"
-#include "disk_io.h"           /* define FILE_BLOCK_SIZE and read and write block functions */
+#include "disk_io.h"           /* define FILE_BLOCK_SIZE */
 #include "security.h"
+#include "storage.h"           /* define read and write block functions */
 #include "strlcxx.h"           /* in case strlcpy and strlcat are not provided by the system */
 #include "types.h"
 
