@@ -27,6 +27,11 @@
 --
 --
 -- $Log: spelling.c,v $
+-- Revision 1.30  2009/07/19 13:21:44  jsedwards
+-- Added ifdef VERIFY_WRITE around code that reads back objects to verify they
+-- were written correctly, they don't work correctly when nwos_write_block
+-- modifies the upper 4 bytes of the reference in the block.
+--
 -- Revision 1.29  2009/03/10 10:39:39  jsedwards
 -- Moved MAX_SPELLING_SIZE to the objectify.h file and renamed to
 -- MAX_SPELLING_OBJ_SIZE.
@@ -350,6 +355,7 @@ ObjCreateResult nwos_create_public_spelling(char* spelling, ObjRef* ref)
 
 	nwos_add_to_references(ref, get_public_spelling_class_ref());
 
+#ifdef VERIFY_WRITE
 	ptr_spelling_obj = malloc(sizeof(C_struct_Spelling) + length);
 	assert(nwos_read_object_from_disk(ref, ptr_spelling_obj, sizeof(C_struct_Spelling) + length));
 	assert(memcmp(kludge, ptr_spelling_obj, sizeof(C_struct_Spelling) + length) == 0);
@@ -360,6 +366,7 @@ ObjCreateResult nwos_create_public_spelling(char* spelling, ObjRef* ref)
 
 	free(ptr_spelling_obj);
 	ptr_spelling_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
@@ -406,6 +413,7 @@ ObjCreateResult nwos_create_private_spelling(char* spelling, ObjRef* ref)
 
 	nwos_add_to_references(ref, &spelling_class_ref);
 
+#ifdef VERIFY_WRITE
 	ptr_spelling_obj = malloc(sizeof(C_struct_Spelling) + length);
 	assert(nwos_read_object_from_disk(ref, ptr_spelling_obj, sizeof(C_struct_Spelling) + length));
 	assert(memcmp(kludge, ptr_spelling_obj, sizeof(C_struct_Spelling) + length) == 0);
@@ -416,6 +424,7 @@ ObjCreateResult nwos_create_private_spelling(char* spelling, ObjRef* ref)
 
 	free(ptr_spelling_obj);
 	ptr_spelling_obj = NULL;
+#endif
 
 	result = CREATED_NEW;
     }
