@@ -27,9 +27,31 @@
 --
 --
 -- $Log: sync_archive.c,v $
+-- Revision 1.18  2009/07/12 01:57:23  jsedwards
+-- Changed used_private_blocks to 64 bits and added 'll' in print statements
+-- for when printing number of blocks.
+--
+-- Revision 1.17  2009/07/05 00:50:32  jsedwards
+-- Changed to include the new header.h file instead of the disk_io.h file.
+--
+-- Revision 1.16  2009/06/13 12:53:14  jsedwards
+-- Merged changes from Alpha_29.10 branch (version Alpha_29.11).
+--
 -- Revision 1.11.2.1  2009/06/06 15:20:32  jsedwards
 -- Fix Bug #2740516 - Changed to check return value from fgets.
 --
+-- Revision 1.15  2009/04/21 12:14:13  jsedwards
+-- Changed to byte swap chunk_info 64 bit references and 32 bit indexes.
+--
+-- Revision 1.14  2009/04/14 12:32:17  jsedwards
+-- Changed to call new terminate_storage function instead of terminate_disk_io.
+--
+-- Revision 1.13  2009/04/14 11:59:38  jsedwards
+-- Changed to call new initialize_storage function instead of initialize_disk_io.
+--
+-- Revision 1.12  2009/04/09 10:54:25  jsedwards
+-- Changed to read total_chunks from source disk header instead of total_blocks.
+--
 -- Revision 1.11  2009/03/14 23:09:05  jsedwards
 -- Added includes of the new backup.h and chunk_info.h files.
 --
@@ -87,8 +109,10 @@
 #include "config.h"
 #include "disk_io.h"
 #include "gen_id.h"
+#include "header.h"
 #include "log.h"
 #include "progress_bar.h"
+#include "storage.h"
 #include "user_config.h"
 
 
@@ -113,8 +137,7 @@ int main(int argc, char* argv[])
     int j;
     size_t bytes_read;
     int num_blocks;
-    uint32 total_private_blocks;
-    uint32 used_private_blocks;
+    uint64 used_private_blocks;
     uint32 chunk_block_offset;
     uint32 blocks_on_disk;
     char answer[8];
@@ -125,6 +148,7 @@ int main(int argc, char* argv[])
     uint32 hash;
     int chunk_num;
     uint32 used_chunks;
+    uint32 total_chunks;
     Chunk_Info* chunk_info;
     int blocks_with_bad_ids = 0;
 
@@ -151,15 +175,15 @@ int main(int argc, char* argv[])
 
     assert(strcmp(nwos_get_private_objects_path(), argv[2]) == 0);
 
-    nwos_initialize_disk_io(READ_WRITE, DEFAULT_FILE);
+    nwos_initialize_storage(READ_WRITE, DEFAULT_FILE);
 
     nwos_terminate_backup(false, NULL);   /* don't create a backup file */
 
     /* verify that the number of used blocks is consistent with empty disk */
     if (nwos_used_private_blocks != 0 || nwos_used_private_chunks != 0)
     {
-	fprintf(stderr, "ERROR: disk not empty, chunks used: %u  blocks used: %u!.\n", 
-		nwos_used_private_blocks, nwos_used_private_chunks);
+	fprintf(stderr, "ERROR: disk not empty, chunks used: %u  blocks used: %llu!.\n", 
+		nwos_used_private_chunks, nwos_used_private_blocks);
 
 	nwos_terminate_disk_io();
 	exit(1);
@@ -229,8 +253,8 @@ int main(int argc, char* argv[])
 
     memcpy(&disk_header, block, sizeof(disk_header));
 
-    nwos_4_uint8_to_uint32(disk_header.total_blocks, &total_private_blocks);
-    nwos_4_uint8_to_uint32(disk_header.used_blocks, &used_private_blocks);
+    nwos_4_uint8_to_uint32(disk_header.total_chunks, &total_chunks);
+    nwos_8_uint8_to_uint64(disk_header.used_blocks, &used_private_blocks);
     nwos_4_uint8_to_uint32(disk_header.block_offset_to_chunks, &chunk_block_offset);
     nwos_4_uint8_to_uint32(disk_header.used_chunks, &used_chunks);
 
@@ -253,14 +277,14 @@ int main(int argc, char* argv[])
 	  int i;
 	  for (i = 0; i < used_chunks; i++)
 	  {
-	      chunk_info[i].ref = byteswap_uint32(chunk_info[i].ref);
-	      chunk_info[i].used = byteswap_uint16(chunk_info[i].used);
-	      chunk_info[i].index = byteswap_uint16(chunk_info[i].index);
+	      chunk_info[i].ref = byteswap_uint64(chunk_info[i].ref);
+	      chunk_info[i].flags_used = byteswap_uint32(chunk_info[i].flags_used);
+	      chunk_info[i].index = byteswap_uint32(chunk_info[i].index);
 	  }
 	}
 #endif
 
-    blocks_on_disk = total_private_blocks; 
+    blocks_on_disk = total_chunks * BLOCKS_IN_CHUNK; 
 
 
     printf("header: %c%c%c%c %c%c%c%c\n",
@@ -395,7 +419,7 @@ int main(int argc, char* argv[])
 
     close(obj_file_desc);
 
-    nwos_terminate_disk_io();
+    nwos_terminate_storage();
 
     snprintf(msg, sizeof(msg), "Number of blocks written: %d  chunks_used: %u",
 	     num_blocks, nwos_used_private_chunks);
@@ -404,7 +428,7 @@ int main(int argc, char* argv[])
 
     if (used_private_blocks != nwos_used_private_blocks)
     {
-	snprintf(msg, sizeof(msg), "WARNING: used_private_blocks mismatch, disk: %u  compressed %u\n",
+	snprintf(msg, sizeof(msg), "WARNING: used_private_blocks mismatch, disk: %llu  compressed %llu\n",
 		nwos_used_private_blocks, used_private_blocks);
 	fprintf(stderr, "%s\n", msg);
     }
